AdcCalLine

Struct AdcCalLine 

pub struct AdcCalLine<ADCX> { /* private fields */ }
Available on crate feature unstable only.
Line fitting ADC calibration scheme

This scheme implements gain correction based on reference points, and returns readings in mV.

A reference point is a pair of a reference voltage and the corresponding mean raw digital ADC value. Such values are usually stored in efuse bit fields for each supported attenuation.

Also it can be measured in runtime by connecting ADC to reference voltage internally but this method is not so good because actual reference voltage may vary in range 1.0..=1.2 V. Currently this method is used as a fallback (with 1.1 V by default) when calibration data is missing.

This scheme also includes basic calibration (AdcCalBasic).