pub struct DebugAssist<'d> { /* private fields */ }Expand description
The debug assist driver instance.
Implementations
Sourceimpl<'d> DebugAssist<'d>
impl<'d> DebugAssist<'d>
Sourcepub fn new(debug_assist: ASSIST_DEBUG<'d>) -> Self
pub fn new(debug_assist: ASSIST_DEBUG<'d>) -> Self
Creates a new instance in crate::Blocking mode.
Sourcepub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
Available on crate feature unstable only.
pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
unstable only.Registers an interrupt handler for the Debug Assist module.
Replaces any previously registered interrupt handlers.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourceimpl DebugAssist<'_>
impl DebugAssist<'_>
Sourcepub fn internal_sp_monitor(
&mut self,
cpu: usize,
lower_bound: u32,
upper_bound: u32,
)
pub fn internal_sp_monitor( &mut self, cpu: usize, lower_bound: u32, upper_bound: u32, )
Enables SP monitoring on the given CPU. When the SP exceeds the
lower_bound or upper_bound threshold, the module records the PC
pointer and generates an interrupt.
Sourcepub fn enable_sp_monitor(&mut self, lower_bound: u32, upper_bound: u32)
pub fn enable_sp_monitor(&mut self, lower_bound: u32, upper_bound: u32)
Enables SP monitoring on main core. When the SP exceeds the
lower_bound or upper_bound threshold, the module records the PC
pointer and generates an interrupt.
Sourcepub fn disable_sp_monitor(&mut self)
pub fn disable_sp_monitor(&mut self)
Disables SP monitoring on main core.
Sourcepub fn clear_sp_monitor_interrupt(&mut self)
pub fn clear_sp_monitor_interrupt(&mut self)
Clears SP monitoring interrupt on main core.
Sourcepub fn is_sp_monitor_interrupt_set(&self) -> bool
pub fn is_sp_monitor_interrupt_set(&self) -> bool
Returns whether SP monitoring interrupt is set on main core.
Sourcepub fn sp_monitor_pc(&self) -> u32
pub fn sp_monitor_pc(&self) -> u32
Returns SP monitoring PC value on main core.
Sourceimpl DebugAssist<'_>
impl DebugAssist<'_>
Sourcepub fn enable_region0_monitor(
&mut self,
lower_bound: u32,
upper_bound: u32,
reads: bool,
writes: bool,
)
pub fn enable_region0_monitor( &mut self, lower_bound: u32, upper_bound: u32, reads: bool, writes: bool, )
Enables region monitoring of read/write performed by the main CPU in a certain memory region0. Whenever the bus reads or writes in the specified memory region, an interrupt will be triggered. Two memory regions (region0, region1) can be monitored at the same time.
Sourcepub fn disable_region0_monitor(&mut self)
pub fn disable_region0_monitor(&mut self)
Disables region0 monitoring on main core.
Sourcepub fn clear_region0_monitor_interrupt(&mut self)
pub fn clear_region0_monitor_interrupt(&mut self)
Clears region0 monitoring interrupt on main core.
Sourcepub fn is_region0_monitor_interrupt_set(&self) -> bool
pub fn is_region0_monitor_interrupt_set(&self) -> bool
Returns whether region0 monitoring interrupt is set on main core.
Sourcepub fn enable_region1_monitor(
&mut self,
lower_bound: u32,
upper_bound: u32,
reads: bool,
writes: bool,
)
pub fn enable_region1_monitor( &mut self, lower_bound: u32, upper_bound: u32, reads: bool, writes: bool, )
Enables region monitoring of read/write performed by the main CPU in a certain memory region1. Whenever the bus reads or writes in the specified memory region, an interrupt will be triggered.
Sourcepub fn disable_region1_monitor(&mut self)
pub fn disable_region1_monitor(&mut self)
Disables region1 monitoring on main core.
Sourcepub fn clear_region1_monitor_interrupt(&mut self)
pub fn clear_region1_monitor_interrupt(&mut self)
Clears region1 monitoring interrupt on main core.
Sourcepub fn is_region1_monitor_interrupt_set(&self) -> bool
pub fn is_region1_monitor_interrupt_set(&self) -> bool
Returns whether region1 monitoring interrupt is set on main core.
Sourcepub fn region_monitor_pc(&self) -> u32
pub fn region_monitor_pc(&self) -> u32
Returns the region monitoring PC value on main core.