#[non_exhaustive]pub struct WatchdogConfig {
pub swd: bool,
pub rwdt: WatchdogStatus,
pub timg0: WatchdogStatus,
pub timg1: WatchdogStatus,
}Expand description
Watchdog configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.swd: boolEnable the super watchdog timer, which has a trigger time of slightly less than one second.
rwdt: WatchdogStatusConfigures the reset watchdog timer.
timg0: WatchdogStatusConfigures the timg0 watchdog timer.
timg1: WatchdogStatusConfigures the timg1 watchdog timer.
By default, the bootloader does not enable this watchdog timer.