Channel

Struct Channel 

#[non_exhaustive]
pub struct Channel<Dm, CH>
where Dm: DriverMode, CH: DmaChannel,
{ pub rx: ChannelRx<Dm, CH::Rx>, pub tx: ChannelTx<Dm, CH::Tx>, }
DMA Channel.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
rx: ChannelRx<Dm, CH::Rx>

RX half of the channel.

tx: ChannelTx<Dm, CH::Tx>

TX half of the channel.

Implementations

Source

impl<CH> Channel<Blocking, CH>
where CH: DmaChannel,

pub fn new(channel: CH) -> Self

Available on crate feature unstable only.

Creates a new DMA channel driver.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Available on crate feature unstable only.

Sets the interrupt handler for RX and TX interrupts.

Interrupts are not enabled at the peripheral level here.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn listen(&mut self, interrupts: impl Into<EnumSet<DmaInterrupt>>)

Listens for the given interrupts.

pub fn unlisten(&mut self, interrupts: impl Into<EnumSet<DmaInterrupt>>)

Unlistens from the given interrupts.

pub fn interrupts(&mut self) -> EnumSet<DmaInterrupt>

Returns the asserted interrupts.

pub fn clear_interrupts(&mut self, interrupts: impl Into<EnumSet<DmaInterrupt>>)

Resets asserted interrupts.

pub fn set_priority(&mut self, priority: DmaPriority)

Configures the channel priorities.

pub fn into_async(self) -> Channel<Async, CH>

Converts a blocking channel to an async channel.

Source

impl<CH, Dm> Channel<Dm, CH>
where CH: DmaChannel, Dm: DriverMode,

pub fn runtime_ensure_compatible(&self, peripheral: DmaPeripheral)

Available on crate feature unstable only.

Asserts that the channel is compatible with the given peripheral.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<CH> Channel<Async, CH>
where CH: DmaChannel,

pub fn into_blocking(self) -> Channel<Blocking, CH>

Converts an async channel to a blocking channel.