esp_hal::dma

Struct Mem2Mem

pub struct Mem2Mem<'d, M>
where M: Mode,
{ /* private fields */ }
DMA Memory to Memory pseudo-Peripheral

This is a pseudo-peripheral that allows for memory to memory transfers. It is not a real peripheral, but a way to use the DMA engine for memory to memory transfers.

Implementations

Source

impl<'d> Mem2Mem<'d, Blocking>

pub fn new<CH, DM>( channel: Channel<'d, DM, CH>, peripheral: impl DmaEligible, rx_descriptors: &'static mut [DmaDescriptor], tx_descriptors: &'static mut [DmaDescriptor], ) -> Result<Self, DmaError>
where CH: DmaChannelConvert<AnyGdmaChannel>, DM: Mode, Channel<'d, Blocking, CH>: From<Channel<'d, DM, CH>>,

Create a new Mem2Mem instance.

pub fn new_with_chunk_size<CH, DM>( channel: Channel<'d, DM, CH>, peripheral: impl DmaEligible, rx_descriptors: &'static mut [DmaDescriptor], tx_descriptors: &'static mut [DmaDescriptor], chunk_size: usize, ) -> Result<Self, DmaError>
where CH: DmaChannelConvert<AnyGdmaChannel>, DM: Mode, Channel<'d, Blocking, CH>: From<Channel<'d, DM, CH>>,

Create a new Mem2Mem instance with specific chunk size.

pub unsafe fn new_unsafe<CH, DM>( channel: Channel<'d, DM, CH>, peripheral: DmaPeripheral, rx_descriptors: &'static mut [DmaDescriptor], tx_descriptors: &'static mut [DmaDescriptor], chunk_size: usize, ) -> Result<Self, DmaError>
where CH: DmaChannelConvert<AnyGdmaChannel>, DM: Mode, Channel<'d, Blocking, CH>: From<Channel<'d, DM, CH>>,

Create a new Mem2Mem instance.

Safety

You must ensure that your not using DMA for the same peripheral and that your the only one using the DmaPeripheral.

pub fn into_async(self) -> Mem2Mem<'d, Async>

Convert Mem2Mem to an async Mem2Mem.

Source

impl<M> Mem2Mem<'_, M>
where M: Mode,

pub fn start_transfer<'t, TXBUF, RXBUF>( &mut self, rx_buffer: &'t mut RXBUF, tx_buffer: &'t TXBUF, ) -> Result<DmaTransferRx<'_, Self>, DmaError>
where TXBUF: ReadBuffer, RXBUF: WriteBuffer,

Start a memory to memory transfer.