pub trait RxChannelFor<P: DmaEligible>: DmaChannelConvert<PeripheralRxChannel<P>> { }Expand description
Trait implemented for the RX half of split DMA channels that are compatible with a particular peripheral. Accepts complete DMA channels or split halves.
This trait is similar in use to DmaChannelFor.
You can use this in places where a peripheral driver would expect a
DmaRxChannel implementation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<P, RX> RxChannelFor<P> for RXwhere
P: DmaEligible,
RX: DmaChannelConvert<PeripheralRxChannel<P>>,
Available on crate feature
unstable only.