pub fn block_version() -> (u8, u8)Available on crate feature
unstable only.Expand description
Returns the eFuse block version.
see https://github.com/espressif/esp-idf/blob/dc016f5987/components/hal/efuse_hal.c#L27-L30
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.