pub fn rtc_calib_cal_code(
_unit: AdcCalibUnit,
atten: Attenuation,
) -> Option<u16>Available on crate feature
unstable only.Expand description
Returns the ADC reference point digital code for specified attenuation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.