rtc_calib_init_code

Function rtc_calib_init_code 

pub fn rtc_calib_init_code(
    _unit: AdcCalibUnit,
    atten: Attenuation,
) -> Option<u16>
Available on crate feature unstable only.
Returns the ADC initial code for specified attenuation from efuse.

See https://github.com/espressif/esp-idf/blob/027613140/components/efuse/esp32c6/esp_efuse_rtc_calib.c#L35

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.