RtcFunction

Enum RtcFunction 

pub enum RtcFunction {
    Rtc = 0,
    Digital = 1,
}
Available on crate feature unstable only.
RTC function

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Rtc = 0

RTC mode.



Digital = 1

Digital mode.