esp_hal::gpio::interconnect

Struct InputSignal

pub struct InputSignal { /* private fields */ }
A configurable input signal between a peripheral and a GPIO pin.

Multiple input signals can be connected to one pin.

Implementations

Source

impl InputSignal

pub fn number(&self) -> u8

Returns the GPIO number of the underlying pin.

pub fn level(&self) -> Level

Returns the current signal level.

pub fn invert(&mut self)

Inverts the peripheral’s input signal.

Calling this function multiple times toggles the setting.

pub fn inverted(self) -> Self

Consumes the signal and returns a new one that inverts the peripheral’s input signal.

Calling this function multiple times toggles the setting.