esp_hal::gpio::interconnect

Struct OutputSignal

pub struct OutputSignal { /* private fields */ }
A configurable output signal between a peripheral and a GPIO pin.

Multiple pins can be connected to one output signal.

Implementations

Source

impl OutputSignal

pub fn number(&self) -> u8

Returns the GPIO number of the underlying pin.

pub fn invert(&mut self)

Inverts the peripheral’s output signal.

Calling this function multiple times toggles the setting.

pub fn inverted(self) -> Self

Consumes the signal and returns a new one that inverts the peripheral’s output signal.

Calling this function multiple times toggles the setting.