esp_hal::gpio

Struct Flex

pub struct Flex<'d, P = AnyPin> { /* private fields */ }
Flexible pin driver.

This driver allows changing the pin mode between input and output.

Implementations

Source

impl<P> Flex<'_, P>
where P: InputPin,

pub async fn wait_for_high(&mut self)

Wait until the pin is high. If it is already high, return immediately.

pub async fn wait_for_low(&mut self)

Wait until the pin is low. If it is already low, return immediately.

pub async fn wait_for_rising_edge(&mut self)

Wait for the pin to undergo a transition from low to high.

pub async fn wait_for_falling_edge(&mut self)

Wait for the pin to undergo a transition from high to low.

pub async fn wait_for_any_edge(&mut self)

Wait for the pin to undergo any transition, i.e low to high OR high to low.

Source

impl<'d> Flex<'d>

pub fn new(pin: impl Peripheral<P = impl Into<AnyPin>> + 'd) -> Self

Create flexible pin driver for a Pin. No mode change happens.

Source

impl<'d, P> Flex<'d, P>
where P: Pin,

pub fn new_typed(pin: impl Peripheral<P = P> + 'd) -> Self

Create flexible pin driver for a Pin. No mode change happens.

pub fn peripheral_input(&self) -> InputSignal

Returns a peripheral input connected to this pin.

The input signal can be passed to peripherals in place of an input pin.

Source

impl<P> Flex<'_, P>
where P: InputPin,

pub fn set_as_input(&mut self, pull: Pull)

Set the GPIO to input mode.

pub fn is_high(&self) -> bool

Get whether the pin input level is high.

pub fn is_low(&self) -> bool

Get whether the pin input level is low.

pub fn level(&self) -> Level

Get the current pin input level.

pub fn listen(&mut self, event: Event)

Listen for interrupts

pub fn unlisten(&mut self)

Stop listening for interrupts

pub fn clear_interrupt(&mut self)

Clear the interrupt status bit for this Pin

pub fn is_interrupt_set(&self) -> bool

Checks if the interrupt status bit for this Pin is set

pub fn wakeup_enable(&mut self, enable: bool, event: WakeEvent)

Enable as a wake-up source.

This will unlisten for interrupts

Source

impl<P> Flex<'_, P>
where P: OutputPin,

pub fn set_as_output(&mut self)

Set the GPIO to output mode.

pub fn set_high(&mut self)

Set the output as high.

pub fn set_low(&mut self)

Set the output as low.

pub fn set_level(&mut self, level: Level)

Set the output level.

pub fn is_set_high(&self) -> bool

Is the output pin set as high?

pub fn is_set_low(&self) -> bool

Is the output pin set as low?

pub fn output_level(&self) -> Level

What level output is set to

pub fn toggle(&mut self)

Toggle pin output

pub fn set_drive_strength(&mut self, strength: DriveStrength)

Configure the DriveStrength of the pin

pub fn set_as_open_drain(&mut self, pull: Pull)

Set the GPIO to open-drain mode.

pub fn split(self) -> (InputSignal, OutputSignal)

Split the pin into an input and output signal.

Peripheral signals allow connecting peripherals together without using external hardware.

pub fn into_peripheral_output(self) -> OutputSignal

Turns the pin object into a peripheral output.

The output signal can be passed to peripherals in place of an output pin.