Output

Struct Output 

pub struct Output<'d> { /* private fields */ }
Push-pull digital output.

This driver configures the GPIO pin to be an output driver.

Implementations

Source

impl<'d> Output<'d>

pub fn into_lp<const PIN: u8>(self) -> Result<LowPowerOutput<'d, PIN>, Self>

Available on crate feature unstable only.

Hands the pin over to the low-power core.

PIN is the low-power pin number, which is how low-power core firmware refers to the pin.

Errors

The original driver when the pad is not the low-power pin numbered PIN.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn into_open_drain_lp<const PIN: u8>( self, ) -> Result<LowPowerOutputOpenDrain<'d, PIN>, Self>

Available on crate feature unstable only.

Hands the pin over to the low-power core as an open-drain output.

PIN is the low-power pin number, which is how low-power core firmware refers to the pin. The pad’s pull-up is enabled, regardless of the driver’s configuration.

Errors

The original driver when the pad is not the low-power pin numbered PIN.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> Output<'d>

pub fn new( pin: impl OutputPin + 'd, initial_level: Level, config: OutputConfig, ) -> Self

Creates a new GPIO output driver.

The initial_level parameter sets the initial output level of the pin. The config parameter sets the drive mode, drive strength, and pull direction of the pin.

Examples

The following example configures GPIO5 to pulse a LED once. The example assumes that the LED is connected such that it is on when the pin is low.

use esp_hal::{
    delay::Delay,
    gpio::{Level, Output, OutputConfig},
};

fn blink_once(led: &mut Output<'_>, delay: &mut Delay) {
    led.set_low();
    delay.delay_millis(500);
    led.set_high();
}

let config = OutputConfig::default();
let mut led = Output::new(peripherals.GPIO5, Level::High, config);
let mut delay = Delay::new();

blink_once(&mut led, &mut delay);
pub fn into_peripheral_output(self) -> OutputSignal<'d>

Available on crate feature unstable only.

Turns the pin object into a peripheral output.

The output signal can be passed to peripherals in place of an output pin.

The returned signal is frozen.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let pin1_gpio = Output::new(peripherals.GPIO1, Level::High, config);
let output = pin1_gpio.into_peripheral_output();
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn apply_config(&mut self, config: &OutputConfig)

Changes the configuration.

Examples
use esp_hal::gpio::{DriveMode, Level, Output, OutputConfig};
let mut pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());

pin.apply_config(&OutputConfig::default().with_drive_mode(DriveMode::OpenDrain));
pub fn set_high(&mut self)

Sets the output as high.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let mut pin = Output::new(peripherals.GPIO5, Level::Low, OutputConfig::default());
pin.set_high();
pub fn set_low(&mut self)

Sets the output as low.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let mut pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());
pin.set_low();
pub fn set_level(&mut self, level: Level)

Sets the output level.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let mut pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());
pin.set_level(Level::Low);
pub fn is_set_high(&self) -> bool

Returns whether the pin is set to high level.

Reads back the value set using set_level, set_high or set_low. Does not need the input stage to be enabled.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());
let is_high = pin.is_set_high();
pub fn is_set_low(&self) -> bool

Returns whether the pin is set to low level.

Reads back the value set using set_level, set_high or set_low. Does not need the input stage to be enabled.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());
let is_low = pin.is_set_low();
pub fn output_level(&self) -> Level

Returns which level the pin is set to.

Reads back the value set using set_level, set_high or set_low. Does not need the input stage to be enabled.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());
let level = pin.output_level();
pub fn toggle(&mut self)

Toggles the pin output.

If the pin was previously set to high, it will be set to low, and vice versa.

Examples
use esp_hal::gpio::{Level, Output, OutputConfig};
let mut pin = Output::new(peripherals.GPIO5, Level::High, OutputConfig::default());
pin.toggle();
pub fn set_pad_hold(&mut self, enable: bool)

Available on crate feature unstable only.

Takes or releases the hold of the pad.

A held pad keeps its level, its function and its resistors, and it ignores this driver.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn is_pad_held(&self) -> bool

Available on crate feature unstable only.

Returns whether something holds the pad.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn into_flex(self) -> Flex<'d>

Available on crate feature unstable only.

Converts the pin driver into a Flex driver.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.