pub trait RtcPin: Pin { }Available on crate feature
unstable only.Expand description
Trait implemented by RTC pins
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".