Hmac

Struct Hmac 

pub struct Hmac<'d> { /* private fields */ }
Provides an interface for interacting with the HMAC hardware peripheral. Computes HMACs for cryptographic purposes and ensures data integrity and authenticity.

Implementations

Source

impl<'d> Hmac<'d>

pub fn new(hmac: HMAC<'d>) -> Self

Creates a new instance of the HMAC peripheral.

pub fn init(&mut self)

Enables the HMAC module.

Before these steps, the peripheral clock bits for HMAC and SHA must be set and the corresponding peripheral reset bits must be cleared.

pub fn configure(&mut self, m: HmacPurpose, key_id: KeyId) -> Result<(), Error>

Configures HMAC keys and key purposes.

pub fn update<'a>(&mut self, msg: &'a [u8]) -> Result<&'a [u8], Infallible>

Processes the message block by block.

Must be called as many times as necessary while msg.len() > 0.

pub fn finalize(&mut self, output: &mut [u8]) -> Result<(), Infallible>

Finalizes the HMAC computation and retrieves the resulting hash output.