Config

Struct Config 

#[non_exhaustive]
pub struct Config { /* private fields */ }
I2C driver configuration

Implementations

Source

impl Config

pub fn with_frequency(self, frequency: Rate) -> Self

Assign the given value to the frequency field.

pub fn frequency(&self) -> Rate

The I2C clock frequency.

Default value: 100 kHz.

pub fn with_timeout(self, timeout: BusTimeout) -> Self

Available on crate feature unstable only.

Assign the given value to the timeout field.

pub fn timeout(&self) -> BusTimeout

Available on crate feature unstable only.

I2C SCL timeout period.

Default value: disabled

pub fn with_software_timeout(self, software_timeout: SoftwareTimeout) -> Self

Assign the given value to the software_timeout field.

pub fn software_timeout(&self) -> SoftwareTimeout

Software timeout.

Default value: disabled.

pub fn with_scl_st_timeout(self, scl_st_timeout: FsmTimeout) -> Self

Available on crate feature unstable only.

Assign the given value to the scl_st_timeout field.

pub fn scl_st_timeout(&self) -> FsmTimeout

Available on crate feature unstable only.

Sets the threshold value for the unchanged period of the SCL_FSM.

Default value: 16.

pub fn with_scl_main_st_timeout(self, scl_main_st_timeout: FsmTimeout) -> Self

Available on crate feature unstable only.

Assign the given value to the scl_main_st_timeout field.

pub fn scl_main_st_timeout(&self) -> FsmTimeout

Available on crate feature unstable only.

Sets the threshold for the unchanged duration of the SCL_MAIN_FSM.

Default value: 16.