esp_hal::i2s::master

Enum DataFormat

pub enum DataFormat {
    Data32Channel32,
    Data32Channel24,
    Data32Channel16,
    Data32Channel8,
    Data16Channel16,
    Data16Channel8,
    Data8Channel8,
}
Supported data formats

Variants



Data32Channel32

32-bit data width and 32-bit channel width.



Data32Channel24

32-bit data width and 24-bit channel width.



Data32Channel16

32-bit data width and 16-bit channel width.



Data32Channel8

32-bit data width and 8-bit channel width.



Data16Channel16

16-bit data width and 16-bit channel width.



Data16Channel8

16-bit data width and 8-bit channel width.



Data8Channel8

8-bit data width and 8-bit channel width.

Implementations

Source

impl DataFormat

pub fn data_bits(&self) -> u8

Returns the number of data bits for the selected data format.

pub fn channel_bits(&self) -> u8

Returns the number of channel bits for the selected data format.