WsWidth

Enum WsWidth 

pub enum WsWidth {
    HalfFrame,
    OneChannel,
    Bit,
    Bits(u16),
}
I2S word select signal width

Variants



HalfFrame

Word select signal will be kept active for half of the frame



OneChannel

Word select signal will be kept active for the length of the first channel (PCM long frame standard)



Bit

Word select signal will be kept active for a single BCLK cycle (PCM short frame standard)



Bits(u16)

Word select signal will be kept active for the specified amount of bits(BCLK cycles)