I2s

Struct I2s 

#[non_exhaustive]
pub struct I2s<'d, Dm>
where Dm: DriverMode,
{ pub i2s_rx: RxCreator<'d, Dm>, pub i2s_tx: TxCreator<'d, Dm>, }
Instance of the I2S peripheral driver.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
i2s_rx: RxCreator<'d, Dm>

Handles the reception (RX) side of the I2S peripheral.

i2s_tx: TxCreator<'d, Dm>

Handles the transmission (TX) side of the I2S peripheral.

Implementations

Source

impl<'d> I2s<'d, Blocking>

pub fn new<I: Instance + 'd>( i2s: I, channel: impl I2sMasterDmaChannel<'d, I>, config: TdmConfig, ) -> Result<Self, ConfigError>

Creates a new I2S instance in TDM mode.

pub fn new_pdm<I: Instance + PdmInstance + 'd>( i2s: I, channel: impl I2sMasterDmaChannel<'d, I>, config: PdmConfig, ) -> Result<Self, ConfigError>

Creates a new I2S instance in PDM mode.

Source

impl<Dm> I2s<'_, Dm>
where Dm: DriverMode,

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Available on crate feature unstable only.

Registers an interrupt handler for the peripheral.

Replaces any previously registered interrupt handlers.

The default/unhandled interrupt handler can be restored with crate::interrupt::DEFAULT_INTERRUPT_HANDLER

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn listen(&mut self, interrupts: impl Into<EnumSet<I2sInterrupt>>)

Available on crate feature unstable only.

Listens for the given interrupts.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn unlisten(&mut self, interrupts: impl Into<EnumSet<I2sInterrupt>>)

Available on crate feature unstable only.

Unlistens from the given interrupts.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn interrupts(&mut self) -> EnumSet<I2sInterrupt>

Available on crate feature unstable only.

Returns the asserted interrupts.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn clear_interrupts(&mut self, interrupts: impl Into<EnumSet<I2sInterrupt>>)

Available on crate feature unstable only.

Resets asserted interrupts.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> I2s<'d, Blocking>

pub fn into_async(self) -> I2s<'d, Async>

Converts the I2S instance into async mode.

Source

impl<'d, Dm> I2s<'d, Dm>
where Dm: DriverMode,

pub fn with_mclk(self, mclk: impl PeripheralOutput<'d>) -> Self

Configures the I2S peripheral to use a master clock (MCLK) output pin.