PdmError

Enum PdmError 

#[non_exhaustive]
pub enum PdmError { UnsupportedInstance, PcmFormatUnsupported, InvalidClock, InvalidSlotMask, DirectionMissing, DuplexUnsupported, InvalidLine, }
PDM configuration errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnsupportedInstance

PDM is not supported on this I2S peripheral instance.



PcmFormatUnsupported

PCM format requested but hardware PCM2PDM/PDM2PCM is unavailable.



InvalidClock

PDM clock configuration is invalid.



InvalidSlotMask

PDM slot mask selects no active channels.



DirectionMissing

PDM config must enable at least one of TX or RX.



DuplexUnsupported

Simultaneous PDM TX and RX is not supported.



InvalidLine

PDM data line index is not available on this chip.