#[repr(u32)]pub enum CpuInterrupt {
Show 32 variants
Interrupt0 = 0,
Interrupt1 = 1,
Interrupt2 = 2,
Interrupt3 = 3,
Interrupt4 = 4,
Interrupt5 = 5,
Interrupt6 = 6,
Interrupt7 = 7,
Interrupt8 = 8,
Interrupt9 = 9,
Interrupt10 = 10,
Interrupt11 = 11,
Interrupt12 = 12,
Interrupt13 = 13,
Interrupt14 = 14,
Interrupt15 = 15,
Interrupt16 = 16,
Interrupt17 = 17,
Interrupt18 = 18,
Interrupt19 = 19,
Interrupt20 = 20,
Interrupt21 = 21,
Interrupt22 = 22,
Interrupt23 = 23,
Interrupt24 = 24,
Interrupt25 = 25,
Interrupt26 = 26,
Interrupt27 = 27,
Interrupt28 = 28,
Interrupt29 = 29,
Interrupt30 = 30,
Interrupt31 = 31,
}unstable only.Expand description
Enumeration of available CPU interrupts.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Variants
Interrupt0 = 0
Interrupt number 0.
Interrupt1 = 1
Interrupt number 1.
Interrupt2 = 2
Interrupt number 2.
Interrupt3 = 3
Interrupt number 3.
Interrupt4 = 4
Interrupt number 4.
Interrupt5 = 5
Interrupt number 5.
Interrupt6 = 6
Interrupt number 6.
Interrupt7 = 7
Interrupt number 7.
Interrupt8 = 8
Interrupt number 8.
Interrupt9 = 9
Interrupt number 9.
Interrupt10 = 10
Interrupt number 10.
Interrupt11 = 11
Interrupt number 11.
Interrupt12 = 12
Interrupt number 12.
Interrupt13 = 13
Interrupt number 13.
Interrupt14 = 14
Interrupt number 14.
Interrupt15 = 15
Interrupt number 15.
Interrupt16 = 16
Interrupt number 16.
Interrupt17 = 17
Interrupt number 17.
Interrupt18 = 18
Interrupt number 18.
Interrupt19 = 19
Interrupt number 19.
Interrupt20 = 20
Interrupt number 20.
Interrupt21 = 21
Interrupt number 21.
Interrupt22 = 22
Interrupt number 22.
Interrupt23 = 23
Interrupt number 23.
Interrupt24 = 24
Interrupt number 24.
Interrupt25 = 25
Interrupt number 25.
Interrupt26 = 26
Interrupt number 26.
Interrupt27 = 27
Interrupt number 27.
Interrupt28 = 28
Interrupt number 28.
Interrupt29 = 29
Interrupt number 29.
Interrupt30 = 30
Interrupt number 30.
Interrupt31 = 31
Interrupt number 31.
Implementations
Sourceimpl CpuInterrupt
impl CpuInterrupt
Sourcepub fn enable(self)
pub fn enable(self)
Enable the CPU interrupt
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn clear(self)
pub fn clear(self)
Clear the CPU interrupt status bit
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn set_kind(self, kind: InterruptKind)
pub fn set_kind(self, kind: InterruptKind)
Set the interrupt kind (i.e. level or edge) of an CPU interrupt
This is safe to call when the vectored feature is enabled. The
vectored interrupt handler will take care of clearing edge interrupt
bits.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn set_priority(self, priority: Priority)
pub fn set_priority(self, priority: Priority)
Set the priority level of a CPU interrupt
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.