esp_hal::interrupt::software

Struct SoftwareInterrupt

#[non_exhaustive]
pub struct SoftwareInterrupt<const NUM: u8>;
A software interrupt can be triggered by software.

Implementations

Source

impl<const NUM: u8> SoftwareInterrupt<NUM>

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Sets the interrupt handler for this software-interrupt

pub fn raise(&self)

Trigger this software-interrupt

pub fn reset(&self)

Resets this software-interrupt

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.