#[non_exhaustive]pub struct SoftwareInterruptControl {
pub software_interrupt0: SoftwareInterrupt<0>,
pub software_interrupt1: SoftwareInterrupt<1>,
pub software_interrupt2: SoftwareInterrupt<2>,
pub software_interrupt3: SoftwareInterrupt<3>,
}Expand description
This gives access to the available software interrupts.
This struct contains several instances of software interrupts that can be used for signaling between different parts of a program or system. Each interrupt is identified by an index (0 to 3).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.software_interrupt0: SoftwareInterrupt<0>Software interrupt 0.
software_interrupt1: SoftwareInterrupt<1>Software interrupt 1.
software_interrupt2: SoftwareInterrupt<2>Software interrupt 2.
software_interrupt3: SoftwareInterrupt<3>Software interrupt 3. Only available when not using esp-hal-embassy,
or on single-core systems.
Implementations
Sourceimpl SoftwareInterruptControl
impl SoftwareInterruptControl
Sourcepub fn new(_peripheral: SW_INTERRUPT) -> Self
pub fn new(_peripheral: SW_INTERRUPT) -> Self
Create a new instance of the software interrupt control.