pub struct InterruptStatus { /* private fields */ }unstable only.Expand description
Representation of peripheral-interrupt status bits.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl InterruptStatus
impl InterruptStatus
Sourcepub fn current() -> InterruptStatus
pub fn current() -> InterruptStatus
Get status of peripheral interrupts
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn is_set(&self, interrupt: u8) -> bool
pub fn is_set(&self, interrupt: u8) -> bool
Is the given interrupt bit set
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn set(&mut self, interrupt: u8)
pub fn set(&mut self, interrupt: u8)
Set the given interrupt status bit
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn iterator(&self) -> InterruptStatusIterator ⓘ
pub fn iterator(&self) -> InterruptStatusIterator ⓘ
Return an iterator over the set interrupt status bits
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.