pub struct PwmUpdateMethod(/* private fields */);Expand description
Settings for when PwmPin::set_timestamp takes effect
Multiple syncing triggers can be set.
Implementations
Sourceimpl PwmUpdateMethod
impl PwmUpdateMethod
Sourcepub const SYNC_IMMEDIATLY: Self
pub const SYNC_IMMEDIATLY: Self
New timestamp will be applied immediately.
Sourcepub const SYNC_ON_ZERO: Self
pub const SYNC_ON_ZERO: Self
New timestamp will be applied when timer is equal to zero.
Sourcepub const SYNC_ON_PERIOD: Self
pub const SYNC_ON_PERIOD: Self
New timestamp will be applied when timer is equal to period.
Sourcepub const fn empty() -> Self
pub const fn empty() -> Self
PwmUpdateMethod with no sync triggers.
Corresponds to syncing immediately
Sourcepub const fn sync_on_timer_equals_zero(self) -> Self
pub const fn sync_on_timer_equals_zero(self) -> Self
Enables syncing new timestamp values when timer is equal to zero.
Sourcepub const fn sync_on_timer_equals_period(self) -> Self
pub const fn sync_on_timer_equals_period(self) -> Self
Enables syncing new timestamp values when timer is equal to period.