Struct esp_hal::peripherals::ATOMIC
source · pub struct ATOMIC { /* private fields */ }Implementations
sourceimpl ATOMIC
impl ATOMIC
sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Methods from Deref<Target = RegisterBlock>
sourcepub fn addr_lock(&self) -> &Reg<ADDR_LOCK_SPEC>
pub fn addr_lock(&self) -> &Reg<ADDR_LOCK_SPEC>
0x00 - hardware lock regsiter
sourcepub fn lr_addr(&self) -> &Reg<LR_ADDR_SPEC>
pub fn lr_addr(&self) -> &Reg<LR_ADDR_SPEC>
0x04 - gloable lr address regsiter
sourcepub fn lr_value(&self) -> &Reg<LR_VALUE_SPEC>
pub fn lr_value(&self) -> &Reg<LR_VALUE_SPEC>
0x08 - gloable lr value regsiter
sourcepub fn lock_status(&self) -> &Reg<LOCK_STATUS_SPEC>
pub fn lock_status(&self) -> &Reg<LOCK_STATUS_SPEC>
0x0c - lock status regsiter
sourcepub fn counter(&self) -> &Reg<COUNTER_SPEC>
pub fn counter(&self) -> &Reg<COUNTER_SPEC>
0x10 - wait counter register