DMA_CH1

Struct DMA_CH1 

#[non_exhaustive]
pub struct DMA_CH1<'a> { /* private fields */ }
Available on crate feature unstable only.
DMA_CH1 peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl DMA_CH1<'_>

pub unsafe fn steal() -> Self

Unsafely creates an instance of this peripheral out of thin air.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub fn reborrow(&mut self) -> DMA_CH1<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method to keep working with the peripheral after the driver that consumes it is dropped.

pub fn bind_dma_in_interrupt(&self, handler: InterruptHandler)

Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn enable_dma_in_interrupt(&self, priority: Priority)

Enables the DMA_IN_CH1 peripheral interrupt on the given priority level.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.

A suitable interrupt handler must be set up before the first interrupt is triggered; otherwise the default handler panics. To set up an interrupt handler, use Self::bind_dma_in_interrupt or create a function that has the same (non-mangled) name as the interrupt to handle.

Examples
use esp_hal::interrupt::Priority;

#[unsafe(no_mangle)]
unsafe extern "C" fn DMA_IN_CH1() {
    // do something
}

peripherals.DMA_CH1.enable_dma_in_interrupt(Priority::Priority1);
peripherals.DMA_CH1.disable_dma_in_interrupt_on_all_cores();
pub fn disable_dma_in_interrupt(&self)

Disables the DMA_IN_CH1 peripheral interrupt handler on the current CPU core.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.
# Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn disable_dma_in_interrupt_on_all_cores(&self)

Disables the DMA_IN_CH1 peripheral interrupt handler on all cores.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.
pub fn bind_dma_out_interrupt(&self, handler: InterruptHandler)

Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn enable_dma_out_interrupt(&self, priority: Priority)

Enables the DMA_OUT_CH1 peripheral interrupt on the given priority level.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.

A suitable interrupt handler must be set up before the first interrupt is triggered; otherwise the default handler panics. To set up an interrupt handler, use Self::bind_dma_out_interrupt or create a function that has the same (non-mangled) name as the interrupt to handle.

Examples
use esp_hal::interrupt::Priority;

#[unsafe(no_mangle)]
unsafe extern "C" fn DMA_OUT_CH1() {
    // do something
}

peripherals.DMA_CH1.enable_dma_out_interrupt(Priority::Priority1);
peripherals.DMA_CH1.disable_dma_out_interrupt_on_all_cores();
pub fn disable_dma_out_interrupt(&self)

Disables the DMA_OUT_CH1 peripheral interrupt handler on the current CPU core.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.
# Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn disable_dma_out_interrupt_on_all_cores(&self)

Disables the DMA_OUT_CH1 peripheral interrupt handler on all cores.

Very low-level interrupt API. Unless writing drivers, this is probably not the interrupt API to use.