GPIO12

Struct GPIO12 

#[non_exhaustive]
pub struct GPIO12<'a> { /* private fields */ }
GPIO12 peripheral singleton (Limitations exist)

This pin may be available with certain limitations. Check your hardware to make sure whether you can use it.
  • These pins may be used to debug the chip using USB.

Implementations

Source

impl<'d> GPIO12<'d>

pub unsafe fn split(self) -> (InputSignal<'d>, OutputSignal<'d>)

Available on crate feature unstable only.

Splits the pin into an input and output signal.

Peripheral signals allow connecting peripherals together without using external hardware.

Safety

The caller must ensure that peripheral drivers do not configure the same GPIO at the same time in multiple places. This includes clones of the InputSignal struct, as well as the OutputSignal struct.

let (rx, tx) = unsafe { peripherals.GPIO2.split() };
// rx and tx can then be passed to different peripherals to connect them.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl GPIO12<'_>

pub unsafe fn steal() -> Self

Unsafely creates an instance of this peripheral out of thin air.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub fn reborrow(&mut self) -> GPIO12<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method to keep working with the peripheral after the driver that consumes it is dropped.