#[non_exhaustive]pub struct GPIO6<'a> { /* private fields */ }Expand description
GPIO6 peripheral singleton (Limitations exist)
- These pins may be used to debug the chip using an external JTAG debugger.
Implementations
Sourceimpl<'d> GPIO6<'d>
impl<'d> GPIO6<'d>
Sourcepub unsafe fn split(self) -> (InputSignal<'d>, OutputSignal<'d>)
Available on crate feature unstable only.
pub unsafe fn split(self) -> (InputSignal<'d>, OutputSignal<'d>)
unstable only.Splits the pin into an input and output signal.
Peripheral signals allow connecting peripherals together without using external hardware.
Safety
The caller must ensure that peripheral drivers do not configure the same
GPIO at the same time in multiple places. This includes clones of the
InputSignal struct, as well as the OutputSignal struct.
let (rx, tx) = unsafe { peripherals.GPIO2.split() };
// rx and tx can then be passed to different peripherals to connect them.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourceimpl GPIO6<'_>
impl GPIO6<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.