HMAC

Struct HMAC 

#[non_exhaustive]
pub struct HMAC<'a> { /* private fields */ }
Available on crate feature unstable only.
HMAC peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl HMAC<'_>

pub unsafe fn steal() -> Self

Unsafely creates an instance of this peripheral out of thin air.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub fn reborrow(&mut self) -> HMAC<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method to keep working with the peripheral after the driver that consumes it is dropped.

Source

impl HMAC<'_>

pub const PTR: *const <HMAC as Deref>::Target = pac::HMAC::PTR

Pointer to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const fn ptr() -> *const <HMAC as Deref>::Target

Return the pointer to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn regs<'a>() -> &'a <HMAC as Deref>::Target

Return a reference to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn register_block(&self) -> &<HMAC as Deref>::Target

Return a reference to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.