esp_hal::peripherals

Struct LP_I2C0

pub struct LP_I2C0 { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl LP_I2C0

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl LP_I2C0

pub const PTR: *const <LP_I2C0 as Deref>::Target = {0x600b1800 as *const <esp32c6::LP_I2C0 as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <LP_I2C0 as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn scl_low_period(&self) -> &Reg<SCL_LOW_PERIOD_SPEC>

0x00 - Configures the low level width of the SCL Clock

pub fn ctr(&self) -> &Reg<CTR_SPEC>

0x04 - Transmission setting

pub fn sr(&self) -> &Reg<SR_SPEC>

0x08 - Describe I2C work status.

pub fn to(&self) -> &Reg<TO_SPEC>

0x0c - Setting time out control for receiving data.

pub fn fifo_st(&self) -> &Reg<FIFO_ST_SPEC>

0x14 - FIFO status register.

pub fn fifo_conf(&self) -> &Reg<FIFO_CONF_SPEC>

0x18 - FIFO configuration register.

pub fn data(&self) -> &Reg<DATA_SPEC>

0x1c - Rx FIFO read data.

pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>

0x20 - Raw interrupt status

pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>

0x24 - Interrupt clear bits

pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>

0x28 - Interrupt enable bits

pub fn int_st(&self) -> &Reg<INT_ST_SPEC>

0x2c - Status of captured I2C communication events

pub fn sda_hold(&self) -> &Reg<SDA_HOLD_SPEC>

0x30 - Configures the hold time after a negative SCL edge.

pub fn sda_sample(&self) -> &Reg<SDA_SAMPLE_SPEC>

0x34 - Configures the sample time after a positive SCL edge.

pub fn scl_high_period(&self) -> &Reg<SCL_HIGH_PERIOD_SPEC>

0x38 - Configures the high level width of SCL

pub fn scl_start_hold(&self) -> &Reg<SCL_START_HOLD_SPEC>

0x40 - Configures the delay between the SDA and SCL negative edge for a start condition

pub fn scl_rstart_setup(&self) -> &Reg<SCL_RSTART_SETUP_SPEC>

0x44 - Configures the delay between the positive edge of SCL and the negative edge of SDA

pub fn scl_stop_hold(&self) -> &Reg<SCL_STOP_HOLD_SPEC>

0x48 - Configures the delay after the SCL clock edge for a stop condition

pub fn scl_stop_setup(&self) -> &Reg<SCL_STOP_SETUP_SPEC>

0x4c - Configures the delay between the SDA and SCL positive edge for a stop condition

pub fn filter_cfg(&self) -> &Reg<FILTER_CFG_SPEC>

0x50 - SCL and SDA filter configuration register

pub fn clk_conf(&self) -> &Reg<CLK_CONF_SPEC>

0x54 - I2C CLK configuration register

pub fn comd(&self, n: usize) -> &Reg<COMD_SPEC>

0x58..0x78 - I2C command register %s

pub fn comd_iter(&self) -> impl Iterator<Item = &Reg<COMD_SPEC>>

Iterator for array of: 0x58..0x78 - I2C command register %s

pub fn scl_st_time_out(&self) -> &Reg<SCL_ST_TIME_OUT_SPEC>

0x78 - SCL status time out register

pub fn scl_main_st_time_out(&self) -> &Reg<SCL_MAIN_ST_TIME_OUT_SPEC>

0x7c - SCL main status time out register

pub fn scl_sp_conf(&self) -> &Reg<SCL_SP_CONF_SPEC>

0x80 - Power configuration register

pub fn date(&self) -> &Reg<DATE_SPEC>

0xf8 - Version register

pub fn txfifo_start_addr(&self) -> &Reg<TXFIFO_START_ADDR_SPEC>

0x100 - I2C TXFIFO base address register

pub fn rxfifo_start_addr(&self) -> &Reg<RXFIFO_START_ADDR_SPEC>

0x180 - I2C RXFIFO base address register