#[non_exhaustive]pub struct MEM_MONITOR<'a> { /* private fields */ }unstable only.Expand description
MEM_MONITOR peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl MEM_MONITOR<'_>
impl MEM_MONITOR<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> MEM_MONITOR<'_>
pub fn reborrow(&mut self) -> MEM_MONITOR<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after the driver that consumes it is dropped.
Sourceimpl MEM_MONITOR<'_>
impl MEM_MONITOR<'_>
Sourcepub const PTR: *const <MEM_MONITOR as Deref>::Target = pac::MEM_MONITOR::PTR
pub const PTR: *const <MEM_MONITOR as Deref>::Target = pac::MEM_MONITOR::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <MEM_MONITOR as Deref>::Target
pub const fn ptr() -> *const <MEM_MONITOR as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <MEM_MONITOR as Deref>::Target
pub fn regs<'a>() -> &'a <MEM_MONITOR as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<MEM_MONITOR as Deref>::Target
pub fn register_block(&self) -> &<MEM_MONITOR as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.