#[non_exhaustive]pub struct PCR<'a> { /* private fields */ }unstable only.Expand description
PCR peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl PCR<'_>
impl PCR<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourceimpl PCR<'_>
impl PCR<'_>
Sourcepub const PTR: *const <PCR as Deref>::Target = pac::PCR::PTR
pub const PTR: *const <PCR as Deref>::Target = pac::PCR::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <PCR as Deref>::Target
pub const fn ptr() -> *const <PCR as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.