Struct esp_hal::peripherals::RNG
source · pub struct RNG { /* private fields */ }Implementations
sourceimpl RNG
impl RNG
sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Methods from Deref<Target = RegisterBlock>