esp_hal::reset

Function reset_reason

pub fn reset_reason() -> Option<SocResetReason>
Retrieves the reason for the last reset as a SocResetReason enum value. Returns None if the reset reason cannot be determined.