LoopMode

Enum LoopMode 

pub enum LoopMode {
    Infinite,
    InfiniteWithInterrupt(u16),
    Finite(u16),
}
Loop mode for continuous transmission

Depending on hardware support, the loopcount interrupt and automatic stopping of the transmission upon reaching a specified loop count may not be available.

Variants



Infinite

Repeat until explicitly stopped.



InfiniteWithInterrupt(u16)

Repeat until explicitly stopped, and assert the loop count interrupt upon completing the given number of iterations.

Loop counts larger than MAX_TX_LOOPCOUNT will result in an error.



Finite(u16)

Repeat for the given number of iterations, and also set the loop count interrupt flag upon completion.

If the iteration count is 0, the transaction will complete immediately without starting the transmitter.

Loop counts larger than MAX_TX_LOOPCOUNT will result in an error.