pub struct TxTransaction<'ch, 'data> { /* private fields */ }Expand description
An in-progress transaction for a single shot TX transaction.
If the data size exceeds the size of the internal buffer, .poll() or
.wait() needs to be called before the entire buffer has been sent to avoid
underruns.
Implementations