pub struct Trng<'d> {
pub rng: Rng,
/* private fields */
}Expand description
True Random Number Generator (TRNG) driver
The Trng struct represents a true random number generator that combines
the randomness from the hardware RNG and an ADC. This struct provides
methods to generate random numbers and fill buffers with random bytes.
Due to pulling the entropy source from the ADC, it uses the associated
registers, so to use TRNG we need to “occupy” the ADC peripheral.
let mut buf = [0u8; 16];
// ADC is not available from now
let mut trng = Trng::new(peripherals.RNG, &mut peripherals.ADC1);
trng.read(&mut buf);
let mut true_rand = trng.random();
let mut rng = trng.downgrade();
// ADC is available now
let analog_pin = peripherals.GPIO3;
let mut adc1_config = AdcConfig::new();
let mut adc1_pin = adc1_config.enable_pin(
analog_pin,
Attenuation::Attenuation11dB
);
let mut adc1 = Adc::<ADC1>::new(peripherals.ADC1, adc1_config);
let pin_value: u16 = nb::block!(adc1.read_oneshot(&mut adc1_pin)).unwrap();
rng.read(&mut buf);
true_rand = rng.random();
let pin_value: u16 = nb::block!(adc1.read_oneshot(&mut adc1_pin)).unwrap();Fields
rng: RngThe hardware random number generator instance.
Implementations
Sourceimpl<'d> Trng<'d>
impl<'d> Trng<'d>
Sourcepub fn new(
rng: impl Peripheral<P = RNG>,
adc: impl Peripheral<P = ADC1> + 'd,
) -> Self
pub fn new( rng: impl Peripheral<P = RNG>, adc: impl Peripheral<P = ADC1> + 'd, ) -> Self