TrngSource

Struct TrngSource 

pub struct TrngSource<'d> { /* private fields */ }
Available on crate feature unstable only.
Ensures random numbers are cryptographically secure.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl<'d> TrngSource<'d>

pub fn new(_rng: RNG<'d>, _adc: ADC1<'d>) -> Self

Enables the SAR ADC entropy source.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub unsafe fn increase_entropy_source_counter()

Increases the internal entropy source counter.

Panics

Panics if the internal counter overflows.

Safety

Must only be called after a new entropy source has been enabled.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn decrease_entropy_source_counter(_private: Internal)

Decreases the internal entropy source counter.

Should only be called before disabling an entropy source (such as the radio).

Should only be called as many times as TrngSource::increase_entropy_source_counter was called.

Panics

Panics if the internal counter underflows. Dropping the TrngSource panics if this method is called more times than TrngSource::increase_entropy_source_counter.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn is_enabled() -> bool

Returns whether the TRNG is currently enabled.

Entropy sources can be disabled at any time.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn try_disable(self) -> Result<(), Self>

Attempts to disable the TRNG.

Panics

Panics if the TRNG is not enabled (i.e. it has been disabled by calling TrngSource::decrease_entropy_source_counter incorrectly).

Errors

TrngSource when there are TRNG users.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.