Rsa

Struct Rsa 

pub struct Rsa<'d, Dm: DriverMode> { /* private fields */ }
RSA peripheral driver.

Implementations

Source

impl<'d> Rsa<'d, Blocking>

pub fn new(rsa: RSA<'d>) -> Self

Creates a new instance in Blocking mode.

Optionally an interrupt handler can be bound.

pub fn into_async(self) -> Rsa<'d, Async>

Reconfigures the RSA driver to operate in asynchronous mode.

pub fn enable_disable_interrupt(&mut self, enable: bool)

Enables or disables the RSA interrupt.

When enabled rsa peripheral would generate an interrupt when a operation is finished.

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Available on crate feature unstable only.

Registers an interrupt handler for the RSA peripheral.

Replaces any previously registered interrupt handlers.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> Rsa<'d, Async>

pub fn into_blocking(self) -> Rsa<'d, Blocking>

Reconfigures the RSA driver to operate in Blocking mode.

Source

impl<'d, Dm: DriverMode> Rsa<'d, Dm>

pub fn disable_constant_time(&mut self, disable: bool)

Enables or disables constant time operation.

Disabling constant time operation increases the performance of modular exponentiation by simplifying the calculation concerning the 0 bits of the exponent. I.e. the less the Hamming weight, the greater the performance.

Compromises security by enabling timing-based side-channel attacks.

For more information refer to the Technical Reference Manual

pub fn search_acceleration(&mut self, enable: bool)

Enables or disables search acceleration.

When enabled it would increase the performance of modular exponentiation by discarding the exponent’s bits before the most significant set bit.

Compromises security by effectively decreasing the key length.

For more information refer to the Technical Reference Manual