Struct esp_hal::rsa::RsaModularMultiplication
source · pub struct RsaModularMultiplication<'a, 'd, T: RsaMode> { /* private fields */ }Expand description
Support for RSA peripheral’s modular multiplication feature that could be
used to find the (operand a * operand b) mod modulus.
Each operand is a little endian byte array of the same size
Implementations
sourceimpl<'a, 'd, T, const N: usize> RsaModularMultiplication<'a, 'd, T>
impl<'a, 'd, T, const N: usize> RsaModularMultiplication<'a, 'd, T>
sourcepub fn new(
rsa: &'a mut Rsa<'d>,
operand_a: &T::InputType,
operand_b: &T::InputType,
modulus: &T::InputType,
m_prime: u32
) -> Self
pub fn new( rsa: &'a mut Rsa<'d>, operand_a: &T::InputType, operand_b: &T::InputType, modulus: &T::InputType, m_prime: u32 ) -> Self
Creates an Instance of RsaModularMultiplication.
m_prime could be calculated using -(modular multiplicative inverse of modulus) mod 2^32, for more information check 19.3.1 in the
https://www.espressif.com/sites/default/files/documentation/esp32-c3_technical_reference_manual_en.pdf
sourcepub fn start_modular_multiplication(&mut self, r: &T::InputType)
pub fn start_modular_multiplication(&mut self, r: &T::InputType)
Starts the modular multiplication operation. r could be calculated
using 2 ^ ( bitlength * 2 ) mod modulus, for more information
check 19.3.1 in the https://www.espressif.com/sites/default/files/documentation/esp32-c3_technical_reference_manual_en.pdf
sourceimpl<'a, 'd, T, const N: usize> RsaModularMultiplication<'a, 'd, T>
impl<'a, 'd, T, const N: usize> RsaModularMultiplication<'a, 'd, T>
sourcepub fn read_results(&mut self, outbuf: &mut T::InputType)
pub fn read_results(&mut self, outbuf: &mut T::InputType)
Reads the result to the given buffer. This is a non blocking function that returns without an error if operation is completed successfully.