WakeupReason

Struct WakeupReason 

pub struct WakeupReason(/* private fields */);
The source(s) that caused the most recent wakeup from sleep.

Returned by wakeup_cause. This is a thin wrapper around the set of WakeupSources that were reported by the hardware. The set is empty if the chip was not woken from sleep.

The available sources depend on the target chip.

Implementations

Source

impl WakeupReason

pub fn is_empty(&self) -> bool

Returns whether the chip was not woken from sleep by any source.

pub fn contains(&self, source: WakeupSource) -> bool

Returns whether the given source caused the most recent wakeup.

pub fn iter(&self) -> impl Iterator<Item = WakeupSource>

Returns an iterator over the sources that caused the most recent wakeup.