pub struct Sha<'d> { /* private fields */ }Expand description
The SHA Accelerator driver instance
Implementations
Sourceimpl<'d> Sha<'d>
impl<'d> Sha<'d>
Sourcepub fn new(sha: impl Peripheral<P = SHA> + 'd) -> Self
pub fn new(sha: impl Peripheral<P = SHA> + 'd) -> Self
Create a new instance of the SHA Accelerator driver.
Sourcepub fn start<'a, A: ShaAlgorithm>(
&'a mut self,
) -> ShaDigest<'d, A, &'a mut Self>
pub fn start<'a, A: ShaAlgorithm>( &'a mut self, ) -> ShaDigest<'d, A, &'a mut Self>
Start a new digest.
Sourcepub fn start_owned<A: ShaAlgorithm>(self) -> ShaDigest<'d, A, Self>
pub fn start_owned<A: ShaAlgorithm>(self) -> ShaDigest<'d, A, Self>
Start a new digest and take ownership of the driver. This is useful for storage outside a function body. i.e. in static or struct.