Sha224Context

Struct Sha224Context 

pub struct Sha224Context(/* private fields */);
A SHA-224 context.

Implementations

Source

impl Sha224Context

pub fn new() -> Self

Creates a new context.

The context represents the in-progress processing of a single message. You need to feed message bytes to Self::update, then finalize the process using Self::finalize.

Any number of contexts can be created, to hash any number of messages concurrently.

pub fn update<'t>(&'t mut self, data: &'t [u8]) -> ShaHandle<'t>

Hashes data.

pub fn finalize<'t>(&'t mut self, result: &mut [u8; 28]) -> ShaHandle<'t>

Finishes the hashing process, writes the final hash to result.

Resets the context to an empty state.

pub fn finalize_into_slice<'t>( &'t mut self, result: &mut [u8], ) -> Result<ShaHandle<'t>, FinalizeError>

Finishes the hashing process, writes the final hash to result.

Resets the context to an empty state.

Returns FinalizeError::BufferTooSmall if result is not large enough to hold the final hash.