pub struct AnySpi<'d>(/* private fields */);Expand description
Any SPI peripheral.
A type-erased version of a peripheral singleton. Useful
for creating arrays of peripherals, or avoiding generics. Peripheral singletons
can be type erased by using their From implementation.
ⓘ
let any_peripheral = AnySpi::from(peripheral);Implementations
Sourceimpl AnySpi<'_>
impl AnySpi<'_>
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> AnySpi<'_>
pub fn reborrow(&mut self) -> AnySpi<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after dropping the driver that consumes this.
See Peripheral singleton section for more information.
Sourcepub fn downcast<P>(self) -> Result<P, Self>where
Self: TryInto<P, Error = Self>,
pub fn downcast<P>(self) -> Result<P, Self>where
Self: TryInto<P, Error = Self>,
Attempts to downcast the pin into the underlying peripheral instance.
Example
// let peri0 = peripherals.PERI0;
// let peri1 = peripherals.PERI1;
let any_peri0 = AnyPeripheral::from(peri0);
let any_peri1 = AnyPeripheral::from(peri1);
let uart0 = any_peri0
.downcast::<PERI0>()
.expect("This downcast succeeds because AnyPeripheral was created from Peri0");
let uart0 = any_peri1
.downcast::<PERI0>()
.expect_err("This AnyPeripheral was created from Peri1, it cannot be downcast to Peri0");Trait Implementations
Sourceimpl<'d> DmaEligiblePeripheral<AhbGdmaChannel<'d>> for AnySpi<'d>
impl<'d> DmaEligiblePeripheral<AhbGdmaChannel<'d>> for AnySpi<'d>
Sourcefn dma_peripheral(&self) -> DmaPeripheral
fn dma_peripheral(&self) -> DmaPeripheral
Returns the
DmaPeripheral ID for runtime compatibility checks.impl Instance for AnySpi<'_>
impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for DMA_CH0<'d>
impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for DMA_CH1<'d>
impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for DMA_CH2<'d>
impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for AhbGdmaChannel<'d>