Struct esp_hal::systimer::Alarm

source ·
pub struct Alarm<MODE, const CHANNEL: u8> { /* private fields */ }

Implementations

source

impl<T, const CHANNEL: u8> Alarm<T, CHANNEL>

source

pub fn enable_interrupt(&self, val: bool)

source

pub fn clear_interrupt(&self)

source

impl<const CHANNEL: u8> Alarm<Target, CHANNEL>

source

pub fn set_target(&self, timestamp: u64)

source

pub fn into_periodic(self) -> Alarm<Periodic, CHANNEL>

source

impl<const CHANNEL: u8> Alarm<Periodic, CHANNEL>

source

pub fn set_period(&self, period: MicrosDurationU32)

source

pub fn into_target(self) -> Alarm<Target, CHANNEL>

source

impl<T> Alarm<T, 0>

source

pub const unsafe fn conjure() -> Self

Conjure an alarm out of thin air.

Safety

Users must take care to ensure that only one reference to the timer is in scope at any given time.

source

impl<T> Alarm<T, 1>

source

pub const unsafe fn conjure() -> Self

Conjure an alarm out of thin air.

Safety

Users must take care to ensure that only one reference to the timer is in scope at any given time.

source

impl<T> Alarm<T, 2>

source

pub const unsafe fn conjure() -> Self

Conjure an alarm out of thin air.

Safety

Users must take care to ensure that only one reference to the timer is in scope at any given time.