esp_hal::timer

Struct OneShotTimer

pub struct OneShotTimer<'d, T> { /* private fields */ }
A one-shot timer.

Implementations

Source

impl<'d, T> OneShotTimer<'d, T>
where T: Timer,

pub fn new(inner: impl Peripheral<P = T> + 'd) -> Self

Construct a new instance of OneShotTimer.

pub fn delay_millis(&self, ms: u32)

Pauses execution for at least ms milliseconds.

pub fn delay_micros(&self, us: u32)

Pauses execution for at least us microseconds.

pub fn delay_nanos(&self, ns: u32)

Pauses execution for at least ns nanoseconds.

pub fn schedule(&mut self, timeout: MicrosDurationU64) -> Result<(), Error>

Start counting until the given timeout and raise an interrupt

pub fn stop(&mut self)

Stop the timer

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Set the interrupt handler

Note that this will replace any previously set interrupt handler

pub fn enable_interrupt(&mut self, enable: bool)

Enable listening for interrupts

pub fn clear_interrupt(&mut self)

Clear the interrupt flag