Struct esp_hal::timer::Wdt

source ·
pub struct Wdt<TG> { /* private fields */ }
Watchdog timer

Implementations

source

impl<TG> Wdt<TG>

Watchdog driver

source

pub fn new() -> Self

Create a new watchdog timer instance

source

pub fn enable(&mut self)

Enable the watchdog timer instance

source

pub fn disable(&mut self)

Disable the watchdog timer instance

source

pub unsafe fn set_wdt_enabled(enabled: bool)

Forcibly enable or disable the watchdog timer

Safety

This bypasses the usual ownership rules for the peripheral, so users must take care to ensure that no driver instance is active for the timer.