Alarm

Struct Alarm 

pub struct Alarm<'d> { /* private fields */ }
An alarm unit.

Implementations

Source

impl Alarm<'_>

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub fn reborrow(&mut self) -> Alarm<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method to keep working with the peripheral after dropping the driver that consumes this.

See Peripheral singleton section for more information.

pub fn set_unit(&self, unit: Unit)

Sets the unit this comparator uses as a reference count.