esp_hal::timer::systimer

Struct SpecificUnit

pub struct SpecificUnit<'d, const CHANNEL: u8>(/* private fields */);
A specific Unit. i.e. Either unit 0 or unit 1.

Implementations

Source

impl SpecificUnit<'static, 0>

pub const unsafe fn conjure() -> Self

Conjure a system timer unit out of thin air.

Safety

Users must take care to ensure that only one reference to the unit is in scope at any given time.

Source

impl SpecificUnit<'static, 1>

pub const unsafe fn conjure() -> Self

Conjure a system timer unit out of thin air.

Safety

Users must take care to ensure that only one reference to the unit is in scope at any given time.