Wdt

Struct Wdt 

pub struct Wdt<TG> { /* private fields */ }
Watchdog timer

Implementations

Source

impl<TG> Wdt<TG>
where TG: TimerGroupInstance,

Watchdog driver

pub fn new() -> Self

Creates a new instance of Wdt.

pub fn enable(&mut self)

Enables the watchdog timer instance.

pub fn disable(&mut self)

Disables the watchdog timer instance.

pub unsafe fn set_wdt_enabled(&mut self, enabled: bool)

Forcibly enable or disable the watchdog timer

Safety

This bypasses the usual ownership rules for the peripheral, so users must take care to ensure that no driver instance is active for the timer.

pub fn feed(&mut self)

Feeds the watchdog timer.

pub fn set_timeout(&mut self, stage: MwdtStage, timeout: Duration)

Sets the timeout, in microseconds, of the watchdog timer.

pub fn set_stage_action(&mut self, stage: MwdtStage, action: MwdtStageAction)

Sets the stage action of the MWDT for a specific stage.

Modifies MWDT behavior only if a custom bootloader with the following modifications is used:

  • ESP_TASK_WDT_EN parameter disabled
  • ESP_INT_WDT parameter disabled