RxConfig

Struct RxConfig 

#[non_exhaustive]
pub struct RxConfig { /* private fields */ }
UHCI Rx Configuration

Implementations

Source

impl RxConfig

pub fn with_chunk_limit(self, chunk_limit: u16) -> Self

Assign the given value to the chunk_limit field.

pub fn chunk_limit(&self) -> u16

The limit of how much to read in a single read call. It cannot be higher than the dma buffer size, otherwise uart/dma/uhci will freeze. It cannot exceed 4095 (12 bits), above this value it will simply also split the readings