pub struct AdcCalBasic<ADCX> { /* private fields */ }Available on crate feature
unstable only.Expand description
Basic ADC calibration scheme
Basic calibration sets the initial ADC bias value so that a zero voltage gives a reading of zero. The correct bias value is usually stored in efuse, but can also be measured at runtime by connecting the ADC input to ground internally.
Failing to apply basic calibration can substantially reduce the ADC’s output range because bias correction is done before the ADC’s output is truncated to 12 bits.