DmaError

Enum DmaError 

pub enum DmaError {
    InvalidAlignment(DmaAlignmentError),
    OutOfDescriptors,
    DescriptorError,
    Overflow,
    BufferTooSmall,
    UnsupportedMemoryRegion,
    InvalidChunkSize,
    Late,
}
DMA Errors

Variants



InvalidAlignment(DmaAlignmentError)

The alignment of data is invalid



OutOfDescriptors

More descriptors are needed for the buffer size



DescriptorError

DescriptorError the DMA rejected the descriptor configuration. This could be because the source address of the data is not in RAM. Ensure your source data is in a valid address space.



Overflow

The available free buffer is less than the amount of data to push



BufferTooSmall

The given buffer is too small



UnsupportedMemoryRegion

Descriptors or buffers are not located in a supported memory region



InvalidChunkSize

Invalid DMA chunk size



Late

Indicates writing to or reading from a circular DMA transaction is done too late and the DMA buffers already overrun / underrun.