esp_hal::dma

Struct Channel

pub struct Channel<'d, M, CH>
where M: Mode, CH: DmaChannel,
{ pub rx: ChannelRx<'d, M, CH>, pub tx: ChannelTx<'d, M, CH>, }
DMA Channel

Fields

rx: ChannelRx<'d, M, CH>

RX half of the channel

tx: ChannelTx<'d, M, CH>

TX half of the channel

Implementations

Source

impl<CH: DmaChannel, M: Mode> Channel<'_, M, CH>

pub fn runtime_ensure_compatible<P: DmaEligible>( &self, _peripheral: &PeripheralRef<'_, P>, )

Asserts that the channel is compatible with the given peripheral.

Source

impl<'d, CH> Channel<'d, Blocking, CH>
where CH: DmaChannel,

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
where CH: DmaChannel,

Sets the interrupt handler for RX and TX interrupts.

Interrupts are not enabled at the peripheral level here.

pub fn listen(&mut self, interrupts: impl Into<EnumSet<DmaInterrupt>>)

Listen for the given interrupts

pub fn unlisten(&mut self, interrupts: impl Into<EnumSet<DmaInterrupt>>)

Unlisten the given interrupts

pub fn interrupts(&mut self) -> EnumSet<DmaInterrupt>

Gets asserted interrupts

pub fn clear_interrupts(&mut self, interrupts: impl Into<EnumSet<DmaInterrupt>>)

Resets asserted interrupts

pub fn configure(&mut self, burst_mode: bool, priority: DmaPriority)

Configure the channel.

pub fn into_async(self) -> Channel<'d, Async, CH>

Converts a blocking channel to an async channel.

Source

impl<'d, CH> Channel<'d, Async, CH>
where CH: DmaChannel,

pub fn into_blocking(self) -> Channel<'d, Blocking, CH>

Converts an async channel to a blocking channel.