esp_hal::ecc

Struct Ecc

pub struct Ecc<'d, DM: Mode> { /* private fields */ }
The ECC Accelerator driver instance

Implementations

Source

impl<'d> Ecc<'d, Blocking>

pub fn new(ecc: impl Peripheral<P = ECC> + 'd) -> Self

Create a new instance in crate::Blocking mode.

Source

impl<DM: Mode> Ecc<'_, DM>

pub fn reset(&mut self)

Resets the ECC peripheral.

pub fn affine_point_multiplication( &mut self, curve: &EllipticCurve, k: &[u8], x: &mut [u8], y: &mut [u8], ) -> Result<(), Error>

Base point multiplication

Base Point Multiplication can be represented as: (Q_x, Q_y) = k * (P_x, P_y)

Output is stored in x and y.

Error

This function will return an error if any bitlength value is different from the bitlength of the prime fields of the curve.

pub fn affine_point_verification( &mut self, curve: &EllipticCurve, x: &[u8], y: &[u8], ) -> Result<(), Error>

Base Point Verification

Base Point Verification can be used to verify if a point (Px, Py) is on a selected elliptic curve.

Error

This function will return an error if any bitlength value is different from the bitlength of the prime fields of the curve.

This function will return an error if the point is not on the selected elliptic curve.

pub fn affine_point_verification_multiplication( &mut self, curve: &EllipticCurve, k: &[u8], x: &mut [u8], y: &mut [u8], ) -> Result<(), Error>

Base Point Verification + Base Point Multiplication

In this working mode, ECC first verifies if Point (P_x, P_y) is on the selected elliptic curve or not. If yes, then perform the multiplication: (Q_x, Q_y) = k * (P_x, P_y)

Output is stored in x and y.

Error

This function will return an error if any bitlength value is different from the bitlength of the prime fields of the curve.

This function will return an error if the point is not on the selected elliptic curve.

pub fn jacobian_point_multiplication( &mut self, curve: &EllipticCurve, k: &mut [u8], x: &mut [u8], y: &mut [u8], ) -> Result<(), Error>

Jacobian Point Multiplication

Jacobian Point Multiplication can be represented as: (Q_x, Q_y, Q_z) = k * (P_x, P_y, 1)

Output is stored in x, y, and k.

Error

This function will return an error if any bitlength value is different from the bitlength of the prime fields of the curve.

pub fn jacobian_point_verification( &mut self, curve: &EllipticCurve, x: &[u8], y: &[u8], z: &[u8], ) -> Result<(), Error>

Jacobian Point Verification

Jacobian Point Verification can be used to verify if a point (Q_x, Q_y, Q_z) is on a selected elliptic curve.

Error

This function will return an error if any bitlength value is different from the bitlength of the prime fields of the curve.

This function will return an error if the point is not on the selected elliptic curve.

pub fn affine_point_verification_jacobian_multiplication( &mut self, curve: &EllipticCurve, k: &mut [u8], x: &mut [u8], y: &mut [u8], ) -> Result<(), Error>

Base Point Verification + Jacobian Point Multiplication

In this working mode, ECC first verifies if Point (Px, Py) is on the selected elliptic curve or not. If yes, then perform the multiplication: (Q_x, Q_y, Q_z) = k * (P_x, P_y, 1)

Output is stored in x, y, and k.

Error

This function will return an error if any bitlength value is different from the bitlength of the prime fields of the curve.

This function will return an error if the point is not on the selected elliptic curve.