pub enum AdcCalibUnit {
ADC1,
ADC2,
}Available on crate feature
unstable only.Expand description
Selects which ADC we are interested in the efuse calibration data for
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Variants