pub enum AlternateFunction {
Function0 = 0,
Function1 = 1,
Function2 = 2,
Function3 = 3,
Function4 = 4,
Function5 = 5,
}Expand description
Alternate functions
GPIO pins can be configured for various functions, such as GPIO
or being directly connected to a peripheral’s signal like UART, SPI, etc.
The AlternateFunction enum allows selecting one of several functions that
a pin can perform, rather than using it as a general-purpose input or
output.
The different variants correspond to different functionality depending on the chip and the specific pin. For more information, refer to your chip’s Technical Reference Manual
Variants
Function0 = 0
Alternate function 0.
Function1 = 1
Alternate function 1.
Function2 = 2
Alternate function 2.
Function3 = 3
Alternate function 3.
Function4 = 4
Alternate function 4.
Function5 = 5
Alternate function 5.