pub struct InputConnection(/* private fields */);Expand description
A peripheral input signal connection.
This is mainly intended for internal use, but it can be used to connect peripherals within the MCU without external hardware.