pub struct OutputConnection(/* private fields */);Expand description
A peripheral (input and) output signal connection.
This is mainly intended for internal use, but it can be used to connect peripherals within the MCU without external hardware.