pub struct OutputSignal { /* private fields */ }Expand description
A configurable output signal between a peripheral and a GPIO pin.
Multiple pins can be connected to one output signal.
Implementations
Sourceimpl OutputSignal
impl OutputSignal