esp_hal::gpio

Struct AnyPin

pub struct AnyPin(/* private fields */);
Type-erased GPIO pin

Implementations

Source

impl AnyPin

pub fn split(self) -> (InputSignal, OutputSignal)

Split the pin into an input and output signal.

Peripheral signals allow connecting peripherals together without using external hardware.