pub struct AnyPin(/* private fields */);Expand description
Type-erased GPIO pin
Implementations
Sourceimpl AnyPin
impl AnyPin
Sourcepub fn split(self) -> (InputSignal, OutputSignal)
pub fn split(self) -> (InputSignal, OutputSignal)
Split the pin into an input and output signal.
Peripheral signals allow connecting peripherals together without using external hardware.