esp_hal::gpio

Struct GpioPin

pub struct GpioPin<const GPIONUM: u8>;
GPIO pin

Implementations

Source

impl<const GPIONUM: u8> GpioPin<GPIONUM>
where Self: Pin,

pub unsafe fn steal() -> Self

Create a pin out of thin air.

Safety

Ensure that only one instance of a pin exists at one time.

pub fn split(self) -> (InputSignal, OutputSignal)

Split the pin into an input and output signal.

Peripheral signals allow connecting peripherals together without using external hardware.