esp_hal::i2c::master

Struct Config

pub struct Config {
    pub frequency: HertzU32,
    pub timeout: Option<u32>,
}
I2C driver configuration

Fields

frequency: HertzU32

The I2C clock frequency.

timeout: Option<u32>

I2C SCL timeout period.

When the level of SCL remains unchanged for more than timeout bus clock cycles, the bus goes to idle state.

The default value is about 10 bus clock cycles.

Note that the effective timeout may be longer than the value configured here. Configuring None disables timeout control.