PriorityError

Enum PriorityError 

pub enum PriorityError {
    InvalidInterruptPriority,
}
Available on crate feature unstable only.
Priority Level Error

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



InvalidInterruptPriority

The priority is not valid