pub struct PwmPin<'d, PWM, const OP: u8, const IS_A: bool> { /* private fields */ }Expand description
A pin driven by an MCPWM operator.
Implementations
Sourceimpl<'d, PWM: PwmPeripheral, const OP: u8, const IS_A: bool> PwmPin<'d, PWM, OP, IS_A>
impl<'d, PWM: PwmPeripheral, const OP: u8, const IS_A: bool> PwmPin<'d, PWM, OP, IS_A>
Sourcepub fn set_actions(&mut self, value: PwmActions<IS_A>)
pub fn set_actions(&mut self, value: PwmActions<IS_A>)
Configures what actions should be taken on timing events.
Sourcepub fn set_update_method(&mut self, update_method: PwmUpdateMethod)
pub fn set_update_method(&mut self, update_method: PwmUpdateMethod)
Sets how a new timestamp syncs with the timer.
Sourcepub fn set_timestamp(&mut self, value: u16)
pub fn set_timestamp(&mut self, value: u16)
Writes a new timestamp.
The written value will take effect according to the set
PwmUpdateMethod.
Sourcepub fn timestamp(&self) -> u16
pub fn timestamp(&self) -> u16
Returns the old timestamp.
The value of the timestamp will take effect according to the set
PwmUpdateMethod.