Peripheral Instances
This module creates singleton instances for each of the various peripherals, and re-exports them to allow users to access and use them in their applications.
Should be noted that that the module also re-exports the Interrupt enum from the PAC, allowing users to handle interrupts associated with these peripherals.
Structs
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- The
Peripheralsstruct provides access to all of the hardware peripherals on the chip. - Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
- Represents a virtual peripheral with no associated hardware.
Enums
- Enumeration of all the interrupts.