Module esp_hal::peripherals

source ·
Peripheral Instances

This module creates singleton instances for each of the various peripherals, and re-exports them to allow users to access and use them in their applications.

Should be noted that that the module also re-exports the Interrupt enum from the PAC, allowing users to handle interrupts associated with these peripherals.

Structs

Enums