Struct esp_hal::peripherals::ADC1

source ·
pub struct ADC1 { /* private fields */ }

Implementations

source

impl ADC1

source

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.