#[non_exhaustive]pub struct BT<'a> { /* private fields */ }unstable only.Expand description
BT peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl BT<'_>
impl BT<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> BT<'_>
pub fn reborrow(&mut self) -> BT<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after the driver that consumes it is dropped.
Sourcepub fn bind_lp_timer_interrupt(&self, handler: InterruptHandler)
pub fn bind_lp_timer_interrupt(&self, handler: InterruptHandler)
Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn enable_lp_timer_interrupt(&self, priority: Priority)
pub fn enable_lp_timer_interrupt(&self, priority: Priority)
Enables the LP_TIMER peripheral interrupt on the given priority level.
A suitable interrupt handler must be set up before the first interrupt
is triggered; otherwise the default handler panics.
To set up an interrupt handler, use Self::bind_lp_timer_interrupt or create a function that has the same (non-mangled) name as the interrupt to handle.
Examples
use esp_hal::interrupt::Priority;
#[unsafe(no_mangle)]
unsafe extern "C" fn LP_TIMER() {
// do something
}
peripherals.BT.enable_lp_timer_interrupt(Priority::Priority1);
peripherals.BT.disable_lp_timer_interrupt_on_all_cores();Sourcepub fn disable_lp_timer_interrupt(&self)
pub fn disable_lp_timer_interrupt(&self)
Disables the LP_TIMER peripheral interrupt handler on the current CPU core.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn disable_lp_timer_interrupt_on_all_cores(&self)
pub fn disable_lp_timer_interrupt_on_all_cores(&self)
Disables the LP_TIMER peripheral interrupt handler on all cores.
Sourcepub fn bind_mac_interrupt(&self, handler: InterruptHandler)
pub fn bind_mac_interrupt(&self, handler: InterruptHandler)
Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn enable_mac_interrupt(&self, priority: Priority)
pub fn enable_mac_interrupt(&self, priority: Priority)
Enables the BT_MAC peripheral interrupt on the given priority level.
A suitable interrupt handler must be set up before the first interrupt
is triggered; otherwise the default handler panics.
To set up an interrupt handler, use Self::bind_mac_interrupt or create a function that has the same (non-mangled) name as the interrupt to handle.
Examples
use esp_hal::interrupt::Priority;
#[unsafe(no_mangle)]
unsafe extern "C" fn BT_MAC() {
// do something
}
peripherals.BT.enable_mac_interrupt(Priority::Priority1);
peripherals.BT.disable_mac_interrupt_on_all_cores();Sourcepub fn disable_mac_interrupt(&self)
pub fn disable_mac_interrupt(&self)
Disables the BT_MAC peripheral interrupt handler on the current CPU core.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn disable_mac_interrupt_on_all_cores(&self)
pub fn disable_mac_interrupt_on_all_cores(&self)
Disables the BT_MAC peripheral interrupt handler on all cores.