pub struct DMA { /* private fields */ }Expand description
Represents a virtual peripheral with no associated hardware.
This struct is generated by the create_peripheral! macro when the peripheral
is defined as virtual.
Implementations
Sourceimpl DMA
impl DMA
Sourcepub fn bind_dma_in_ch0_interrupt(&mut self, handler: unsafe extern "C" fn())
pub fn bind_dma_in_ch0_interrupt(&mut self, handler: unsafe extern "C" fn())
Binds an interrupt handler to the corresponding interrupt for this peripheral.
Sourcepub fn bind_dma_in_ch1_interrupt(&mut self, handler: unsafe extern "C" fn())
pub fn bind_dma_in_ch1_interrupt(&mut self, handler: unsafe extern "C" fn())
Binds an interrupt handler to the corresponding interrupt for this peripheral.
Sourcepub fn bind_dma_in_ch2_interrupt(&mut self, handler: unsafe extern "C" fn())
pub fn bind_dma_in_ch2_interrupt(&mut self, handler: unsafe extern "C" fn())
Binds an interrupt handler to the corresponding interrupt for this peripheral.
Sourcepub fn bind_dma_out_ch0_interrupt(&mut self, handler: unsafe extern "C" fn())
pub fn bind_dma_out_ch0_interrupt(&mut self, handler: unsafe extern "C" fn())
Binds an interrupt handler to the corresponding interrupt for this peripheral.
Sourcepub fn bind_dma_out_ch1_interrupt(&mut self, handler: unsafe extern "C" fn())
pub fn bind_dma_out_ch1_interrupt(&mut self, handler: unsafe extern "C" fn())
Binds an interrupt handler to the corresponding interrupt for this peripheral.
Sourcepub fn bind_dma_out_ch2_interrupt(&mut self, handler: unsafe extern "C" fn())
pub fn bind_dma_out_ch2_interrupt(&mut self, handler: unsafe extern "C" fn())
Binds an interrupt handler to the corresponding interrupt for this peripheral.
Methods from Deref<Target = RegisterBlock>
Sourcepub fn in_int_ch(&self, n: usize) -> &IN_INT_CH
pub fn in_int_ch(&self, n: usize) -> &IN_INT_CH
0x00..0x30 - Cluster IN_INT_CH%s, containing IN_INT_RAW_CH?, IN_INT_ST_CH?, IN_INT_ENA_CH?, IN_INT_CLR_CH?
Sourcepub fn in_int_ch_iter(&self) -> impl Iterator<Item = &IN_INT_CH>
pub fn in_int_ch_iter(&self) -> impl Iterator<Item = &IN_INT_CH>
Iterator for array of: 0x00..0x30 - Cluster IN_INT_CH%s, containing IN_INT_RAW_CH?, IN_INT_ST_CH?, IN_INT_ENA_CH?, IN_INT_CLR_CH?
Sourcepub fn out_int_ch(&self, n: usize) -> &OUT_INT_CH
pub fn out_int_ch(&self, n: usize) -> &OUT_INT_CH
0x30..0x60 - Cluster OUT_INT_CH%s, containing OUT_INT_RAW_CH?, OUT_INT_ST_CH?, OUT_INT_ENA_CH?, OUT_INT_CLR_CH?
Sourcepub fn out_int_ch_iter(&self) -> impl Iterator<Item = &OUT_INT_CH>
pub fn out_int_ch_iter(&self) -> impl Iterator<Item = &OUT_INT_CH>
Iterator for array of: 0x30..0x60 - Cluster OUT_INT_CH%s, containing OUT_INT_RAW_CH?, OUT_INT_ST_CH?, OUT_INT_ENA_CH?, OUT_INT_CLR_CH?
Sourcepub fn ahb_test(&self) -> &Reg<AHB_TEST_SPEC>
pub fn ahb_test(&self) -> &Reg<AHB_TEST_SPEC>
0x60 - reserved
Sourcepub fn misc_conf(&self) -> &Reg<MISC_CONF_SPEC>
pub fn misc_conf(&self) -> &Reg<MISC_CONF_SPEC>
0x64 - MISC register
Sourcepub fn ch(&self, n: usize) -> &CH
pub fn ch(&self, n: usize) -> &CH
0x70..0x2b0 - Cluster CH%s, containing IN_CONF0_CH?, IN_CONF1_CH?, INFIFO_STATUS_CH?, IN_POP_CH?, IN_LINK_CH?, IN_STATE_CH?, IN_SUC_EOF_DES_ADDR_CH?, IN_ERR_EOF_DES_ADDR_CH?, IN_DSCR_CH?, IN_DSCR_BF0_CH?, IN_DSCR_BF1_CH?, IN_PRI_CH?, IN_PERI_SEL_CH?, OUT_CONF0_CH?, OUT_CONF1_CH?, OUTFIFO_STATUS_CH?, OUT_PUSH_CH?, OUT_LINK_CH?, OUT_STATE_CH?, OUT_EOF_DES_ADDR_CH?, OUT_EOF_BFR_DES_ADDR_CH?, OUT_DSCR_CH?, OUT_DSCR_BF0_CH?, OUT_DSCR_BF1_CH?, OUT_PRI_CH?, OUT_PERI_SEL_CH?
Sourcepub fn ch_iter(&self) -> impl Iterator<Item = &CH>
pub fn ch_iter(&self) -> impl Iterator<Item = &CH>
Iterator for array of: 0x70..0x2b0 - Cluster CH%s, containing IN_CONF0_CH?, IN_CONF1_CH?, INFIFO_STATUS_CH?, IN_POP_CH?, IN_LINK_CH?, IN_STATE_CH?, IN_SUC_EOF_DES_ADDR_CH?, IN_ERR_EOF_DES_ADDR_CH?, IN_DSCR_CH?, IN_DSCR_BF0_CH?, IN_DSCR_BF1_CH?, IN_PRI_CH?, IN_PERI_SEL_CH?, OUT_CONF0_CH?, OUT_CONF1_CH?, OUTFIFO_STATUS_CH?, OUT_PUSH_CH?, OUT_LINK_CH?, OUT_STATE_CH?, OUT_EOF_DES_ADDR_CH?, OUT_EOF_BFR_DES_ADDR_CH?, OUT_DSCR_CH?, OUT_DSCR_BF0_CH?, OUT_DSCR_BF1_CH?, OUT_PRI_CH?, OUT_PERI_SEL_CH?