#[non_exhaustive]pub struct HP_APM<'a> { /* private fields */ }unstable only.Expand description
HP_APM peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl HP_APM<'_>
impl HP_APM<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourceimpl HP_APM<'_>
impl HP_APM<'_>
Sourcepub const PTR: *const <HP_APM as Deref>::Target = pac::HP_APM::PTR
pub const PTR: *const <HP_APM as Deref>::Target = pac::HP_APM::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <HP_APM as Deref>::Target
pub const fn ptr() -> *const <HP_APM as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.