esp_hal::peripherals

Struct HP_APM

pub struct HP_APM { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl HP_APM

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl HP_APM

pub const PTR: *const <HP_APM as Deref>::Target = {0x60099000 as *const <esp32c6::HP_APM as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <HP_APM as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn region_filter_en(&self) -> &Reg<REGION_FILTER_EN_SPEC>

0x00 - Region filter enable register

pub fn region(&self, n: usize) -> &REGION

0x04..0xc4 - Cluster REGION%s, containing REGION*_ADDR_START, REGION*_ADDR_END, REGION*_PMS_ATTR

pub fn region_iter(&self) -> impl Iterator<Item = &REGION>

Iterator for array of: 0x04..0xc4 - Cluster REGION%s, containing REGION*_ADDR_START, REGION*_ADDR_END, REGION*_PMS_ATTR

pub fn func_ctrl(&self) -> &Reg<FUNC_CTRL_SPEC>

0xc4 - PMS function control register

pub fn m(&self, n: usize) -> &M

0xc8..0x108 - Cluster M%s, containing M?_STATUS, M?_STATUS_CLR, M?_EXCEPTION_INFO0, M?_EXCEPTION_INFO1

pub fn m_iter(&self) -> impl Iterator<Item = &M>

Iterator for array of: 0xc8..0x108 - Cluster M%s, containing M?_STATUS, M?_STATUS_CLR, M?_EXCEPTION_INFO0, M?_EXCEPTION_INFO1

pub fn int_en(&self) -> &Reg<INT_EN_SPEC>

0x108 - APM interrupt enable register

pub fn clock_gate(&self) -> &Reg<CLOCK_GATE_SPEC>

0x10c - clock gating register

pub fn date(&self) -> &Reg<DATE_SPEC>

0x7fc - Version register