esp_hal::peripherals

Struct IEEE802154

pub struct IEEE802154 { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl IEEE802154

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl IEEE802154

pub const PTR: *const <IEEE802154 as Deref>::Target = {0x600a3000 as *const <esp32c6::IEEE802154 as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <IEEE802154 as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn command(&self) -> &Reg<COMMAND_SPEC>

0x00 -

pub fn ctrl_cfg(&self) -> &Reg<CTRL_CFG_SPEC>

0x04 -

pub fn inf0_short_addr(&self) -> &Reg<INF0_SHORT_ADDR_SPEC>

0x08 -

pub fn inf0_pan_id(&self) -> &Reg<INF0_PAN_ID_SPEC>

0x0c -

pub fn inf0_extend_addr0(&self) -> &Reg<INF0_EXTEND_ADDR0_SPEC>

0x10 -

pub fn inf0_extend_addr1(&self) -> &Reg<INF0_EXTEND_ADDR1_SPEC>

0x14 -

pub fn inf1_short_addr(&self) -> &Reg<INF1_SHORT_ADDR_SPEC>

0x18 -

pub fn inf1_pan_id(&self) -> &Reg<INF1_PAN_ID_SPEC>

0x1c -

pub fn inf1_extend_addr0(&self) -> &Reg<INF1_EXTEND_ADDR0_SPEC>

0x20 -

pub fn inf1_extend_addr1(&self) -> &Reg<INF1_EXTEND_ADDR1_SPEC>

0x24 -

pub fn inf2_short_addr(&self) -> &Reg<INF2_SHORT_ADDR_SPEC>

0x28 -

pub fn inf2_pan_id(&self) -> &Reg<INF2_PAN_ID_SPEC>

0x2c -

pub fn inf2_extend_addr0(&self) -> &Reg<INF2_EXTEND_ADDR0_SPEC>

0x30 -

pub fn inf2_extend_addr1(&self) -> &Reg<INF2_EXTEND_ADDR1_SPEC>

0x34 -

pub fn inf3_short_addr(&self) -> &Reg<INF3_SHORT_ADDR_SPEC>

0x38 -

pub fn inf3_pan_id(&self) -> &Reg<INF3_PAN_ID_SPEC>

0x3c -

pub fn inf3_extend_addr0(&self) -> &Reg<INF3_EXTEND_ADDR0_SPEC>

0x40 -

pub fn inf3_extend_addr1(&self) -> &Reg<INF3_EXTEND_ADDR1_SPEC>

0x44 -

pub fn channel(&self) -> &Reg<CHANNEL_SPEC>

0x48 -

pub fn tx_power(&self) -> &Reg<TX_POWER_SPEC>

0x4c -

pub fn ed_scan_duration(&self) -> &Reg<ED_SCAN_DURATION_SPEC>

0x50 -

pub fn ed_scan_cfg(&self) -> &Reg<ED_SCAN_CFG_SPEC>

0x54 -

pub fn ifs(&self) -> &Reg<IFS_SPEC>

0x58 -

pub fn ack_timeout(&self) -> &Reg<ACK_TIMEOUT_SPEC>

0x5c -

pub fn event_en(&self) -> &Reg<EVENT_EN_SPEC>

0x60 -

pub fn event_status(&self) -> &Reg<EVENT_STATUS_SPEC>

0x64 -

pub fn rx_abort_intr_ctrl(&self) -> &Reg<RX_ABORT_INTR_CTRL_SPEC>

0x68 -

pub fn ack_frame_pending_en(&self) -> &Reg<ACK_FRAME_PENDING_EN_SPEC>

0x6c -

pub fn coex_pti(&self) -> &Reg<COEX_PTI_SPEC>

0x70 -

pub fn core_dummy_data(&self) -> &Reg<CORE_DUMMY_DATA_SPEC>

0x74 -

pub fn tx_abort_interrupt_control( &self, ) -> &Reg<TX_ABORT_INTERRUPT_CONTROL_SPEC>

0x78 -

pub fn enhance_ack_cfg(&self) -> &Reg<ENHANCE_ACK_CFG_SPEC>

0x7c -

pub fn rx_status(&self) -> &Reg<RX_STATUS_SPEC>

0x80 -

pub fn tx_status(&self) -> &Reg<TX_STATUS_SPEC>

0x84 -

pub fn txrx_status(&self) -> &Reg<TXRX_STATUS_SPEC>

0x88 -

pub fn tx_ccm_schedule_status(&self) -> &Reg<TX_CCM_SCHEDULE_STATUS_SPEC>

0x8c -

pub fn core_gck_cfg(&self) -> &Reg<CORE_GCK_CFG_SPEC>

0x90 -

pub fn test_control(&self) -> &Reg<TEST_CONTROL_SPEC>

0x94 -

pub fn dtm_config(&self) -> &Reg<DTM_CONFIG_SPEC>

0x98 -

pub fn dtm_tx_pkt_config(&self) -> &Reg<DTM_TX_PKT_CONFIG_SPEC>

0x9c -

pub fn dtm_pkt_counter(&self) -> &Reg<DTM_PKT_COUNTER_SPEC>

0xa0 -

pub fn rx_length(&self) -> &Reg<RX_LENGTH_SPEC>

0xa4 -

pub fn time0_threshold(&self) -> &Reg<TIME0_THRESHOLD_SPEC>

0xa8 -

pub fn time0_value(&self) -> &Reg<TIME0_VALUE_SPEC>

0xac -

pub fn time1_threshold(&self) -> &Reg<TIME1_THRESHOLD_SPEC>

0xb0 -

pub fn time1_value(&self) -> &Reg<TIME1_VALUE_SPEC>

0xb4 -

pub fn clk_counter_match_val(&self) -> &Reg<CLK_COUNTER_MATCH_VAL_SPEC>

0xb8 -

pub fn clk_counter(&self) -> &Reg<CLK_COUNTER_SPEC>

0xbc -

pub fn ifs_counter(&self) -> &Reg<IFS_COUNTER_SPEC>

0xc0 -

pub fn sfd_wait_symbol(&self) -> &Reg<SFD_WAIT_SYMBOL_SPEC>

0xc4 -

pub fn txrx_path_delay(&self) -> &Reg<TXRX_PATH_DELAY_SPEC>

0xc8 -

pub fn bb_clk(&self) -> &Reg<BB_CLK_SPEC>

0xcc -

pub fn txdma_addr(&self) -> &Reg<TXDMA_ADDR_SPEC>

0xd0 -

pub fn txdma_ctrl_state(&self) -> &Reg<TXDMA_CTRL_STATE_SPEC>

0xd4 -

pub fn txdma_err(&self) -> &Reg<TXDMA_ERR_SPEC>

0xd8 -

pub fn rxdma_addr(&self) -> &Reg<RXDMA_ADDR_SPEC>

0xe0 -

pub fn rxdma_ctrl_state(&self) -> &Reg<RXDMA_CTRL_STATE_SPEC>

0xe4 -

pub fn rxdma_err(&self) -> &Reg<RXDMA_ERR_SPEC>

0xe8 -

pub fn dma_gck_cfg(&self) -> &Reg<DMA_GCK_CFG_SPEC>

0xf0 -

pub fn dma_dummy(&self) -> &Reg<DMA_DUMMY_SPEC>

0xf4 -

pub fn paon_delay(&self) -> &Reg<PAON_DELAY_SPEC>

0x100 -

pub fn txon_delay(&self) -> &Reg<TXON_DELAY_SPEC>

0x104 -

pub fn txen_stop_delay(&self) -> &Reg<TXEN_STOP_DELAY_SPEC>

0x108 -

pub fn txoff_delay(&self) -> &Reg<TXOFF_DELAY_SPEC>

0x10c -

pub fn rxon_delay(&self) -> &Reg<RXON_DELAY_SPEC>

0x110 -

pub fn txrx_switch_delay(&self) -> &Reg<TXRX_SWITCH_DELAY_SPEC>

0x114 -

pub fn cont_rx_delay(&self) -> &Reg<CONT_RX_DELAY_SPEC>

0x118 -

pub fn dcdc_ctrl(&self) -> &Reg<DCDC_CTRL_SPEC>

0x11c -

pub fn debug_ctrl(&self) -> &Reg<DEBUG_CTRL_SPEC>

0x120 -

pub fn sec_ctrl(&self) -> &Reg<SEC_CTRL_SPEC>

0x128 -

pub fn sec_extend_address0(&self) -> &Reg<SEC_EXTEND_ADDRESS0_SPEC>

0x12c -

pub fn sec_extend_address1(&self) -> &Reg<SEC_EXTEND_ADDRESS1_SPEC>

0x130 -

pub fn sec_key0(&self) -> &Reg<SEC_KEY0_SPEC>

0x134 -

pub fn sec_key1(&self) -> &Reg<SEC_KEY1_SPEC>

0x138 -

pub fn sec_key2(&self) -> &Reg<SEC_KEY2_SPEC>

0x13c -

pub fn sec_key3(&self) -> &Reg<SEC_KEY3_SPEC>

0x140 -

pub fn sfd_timeout_cnt(&self) -> &Reg<SFD_TIMEOUT_CNT_SPEC>

0x144 -

pub fn crc_error_cnt(&self) -> &Reg<CRC_ERROR_CNT_SPEC>

0x148 -

pub fn ed_abort_cnt(&self) -> &Reg<ED_ABORT_CNT_SPEC>

0x14c -

pub fn cca_fail_cnt(&self) -> &Reg<CCA_FAIL_CNT_SPEC>

0x150 -

pub fn rx_filter_fail_cnt(&self) -> &Reg<RX_FILTER_FAIL_CNT_SPEC>

0x154 -

pub fn no_rss_detect_cnt(&self) -> &Reg<NO_RSS_DETECT_CNT_SPEC>

0x158 -

pub fn rx_abort_coex_cnt(&self) -> &Reg<RX_ABORT_COEX_CNT_SPEC>

0x15c -

pub fn rx_restart_cnt(&self) -> &Reg<RX_RESTART_CNT_SPEC>

0x160 -

pub fn tx_ack_abort_coex_cnt(&self) -> &Reg<TX_ACK_ABORT_COEX_CNT_SPEC>

0x164 -

pub fn ed_scan_coex_cnt(&self) -> &Reg<ED_SCAN_COEX_CNT_SPEC>

0x168 -

pub fn rx_ack_abort_coex_cnt(&self) -> &Reg<RX_ACK_ABORT_COEX_CNT_SPEC>

0x16c -

pub fn rx_ack_timeout_cnt(&self) -> &Reg<RX_ACK_TIMEOUT_CNT_SPEC>

0x170 -

pub fn tx_break_coex_cnt(&self) -> &Reg<TX_BREAK_COEX_CNT_SPEC>

0x174 -

pub fn tx_security_error_cnt(&self) -> &Reg<TX_SECURITY_ERROR_CNT_SPEC>

0x178 -

pub fn cca_busy_cnt(&self) -> &Reg<CCA_BUSY_CNT_SPEC>

0x17c -

pub fn error_cnt_clear(&self) -> &Reg<ERROR_CNT_CLEAR_SPEC>

0x180 -

pub fn mac_date(&self) -> &Reg<MAC_DATE_SPEC>

0x184 -