esp_hal::peripherals

Struct INTPRI

pub struct INTPRI { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl INTPRI

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl INTPRI

pub const PTR: *const <INTPRI as Deref>::Target = {0x600c5000 as *const <esp32c6::INTPRI as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <INTPRI as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn cpu_int_enable(&self) -> &Reg<CPU_INT_ENABLE_SPEC>

0x00 - register description

pub fn cpu_int_type(&self) -> &Reg<CPU_INT_TYPE_SPEC>

0x04 - register description

pub fn cpu_int_eip_status(&self) -> &Reg<CPU_INT_EIP_STATUS_SPEC>

0x08 - register description

pub fn cpu_int_pri(&self, n: usize) -> &Reg<CPU_INT_PRI_SPEC>

0x0c..0x8c - register description

pub fn cpu_int_pri_iter(&self) -> impl Iterator<Item = &Reg<CPU_INT_PRI_SPEC>>

Iterator for array of: 0x0c..0x8c - register description

pub fn cpu_int_thresh(&self) -> &Reg<CPU_INT_THRESH_SPEC>

0x8c - register description

pub fn cpu_intr_from_cpu_0(&self) -> &Reg<CPU_INTR_FROM_CPU_0_SPEC>

0x90 - register description

pub fn cpu_intr_from_cpu_1(&self) -> &Reg<CPU_INTR_FROM_CPU_1_SPEC>

0x94 - register description

pub fn cpu_intr_from_cpu_2(&self) -> &Reg<CPU_INTR_FROM_CPU_2_SPEC>

0x98 - register description

pub fn cpu_intr_from_cpu_3(&self) -> &Reg<CPU_INTR_FROM_CPU_3_SPEC>

0x9c - register description

pub fn date(&self) -> &Reg<DATE_SPEC>

0xa0 - register description

pub fn clock_gate(&self) -> &Reg<CLOCK_GATE_SPEC>

0xa4 - register description

pub fn cpu_int_clear(&self) -> &Reg<CPU_INT_CLEAR_SPEC>

0xa8 - register description

pub fn rnd_eco(&self) -> &Reg<RND_ECO_SPEC>

0xac - redcy eco register.

pub fn rnd_eco_low(&self) -> &Reg<RND_ECO_LOW_SPEC>

0xb0 - redcy eco low register.

pub fn rnd_eco_high(&self) -> &Reg<RND_ECO_HIGH_SPEC>

0x3fc - redcy eco high register.