Struct esp_hal::peripherals::LP_I2C0
source · pub struct LP_I2C0 { /* private fields */ }Implementations
sourceimpl LP_I2C0
impl LP_I2C0
sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Methods from Deref<Target = RegisterBlock>
sourcepub fn scl_low_period(&self) -> &Reg<SCL_LOW_PERIOD_SPEC>
pub fn scl_low_period(&self) -> &Reg<SCL_LOW_PERIOD_SPEC>
0x00 - Configures the low level width of the SCL Clock
sourcepub fn fifo_st(&self) -> &Reg<FIFO_ST_SPEC>
pub fn fifo_st(&self) -> &Reg<FIFO_ST_SPEC>
0x14 - FIFO status register.
sourcepub fn fifo_conf(&self) -> &Reg<FIFO_CONF_SPEC>
pub fn fifo_conf(&self) -> &Reg<FIFO_CONF_SPEC>
0x18 - FIFO configuration register.
sourcepub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>
pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>
0x20 - Raw interrupt status
sourcepub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>
pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>
0x24 - Interrupt clear bits
sourcepub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>
pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>
0x28 - Interrupt enable bits
sourcepub fn int_status(&self) -> &Reg<INT_STATUS_SPEC>
pub fn int_status(&self) -> &Reg<INT_STATUS_SPEC>
0x2c - Status of captured I2C communication events
sourcepub fn sda_hold(&self) -> &Reg<SDA_HOLD_SPEC>
pub fn sda_hold(&self) -> &Reg<SDA_HOLD_SPEC>
0x30 - Configures the hold time after a negative SCL edge.
sourcepub fn sda_sample(&self) -> &Reg<SDA_SAMPLE_SPEC>
pub fn sda_sample(&self) -> &Reg<SDA_SAMPLE_SPEC>
0x34 - Configures the sample time after a positive SCL edge.
sourcepub fn scl_high_period(&self) -> &Reg<SCL_HIGH_PERIOD_SPEC>
pub fn scl_high_period(&self) -> &Reg<SCL_HIGH_PERIOD_SPEC>
0x38 - Configures the high level width of SCL
sourcepub fn scl_start_hold(&self) -> &Reg<SCL_START_HOLD_SPEC>
pub fn scl_start_hold(&self) -> &Reg<SCL_START_HOLD_SPEC>
0x40 - Configures the delay between the SDA and SCL negative edge for a start condition
sourcepub fn scl_rstart_setup(&self) -> &Reg<SCL_RSTART_SETUP_SPEC>
pub fn scl_rstart_setup(&self) -> &Reg<SCL_RSTART_SETUP_SPEC>
0x44 - Configures the delay between the positive edge of SCL and the negative edge of SDA
sourcepub fn scl_stop_hold(&self) -> &Reg<SCL_STOP_HOLD_SPEC>
pub fn scl_stop_hold(&self) -> &Reg<SCL_STOP_HOLD_SPEC>
0x48 - Configures the delay after the SCL clock edge for a stop condition
sourcepub fn scl_stop_setup(&self) -> &Reg<SCL_STOP_SETUP_SPEC>
pub fn scl_stop_setup(&self) -> &Reg<SCL_STOP_SETUP_SPEC>
0x4c - Configures the delay between the SDA and SCL positive edge for a stop condition
sourcepub fn filter_cfg(&self) -> &Reg<FILTER_CFG_SPEC>
pub fn filter_cfg(&self) -> &Reg<FILTER_CFG_SPEC>
0x50 - SCL and SDA filter configuration register
sourcepub fn clk_conf(&self) -> &Reg<CLK_CONF_SPEC>
pub fn clk_conf(&self) -> &Reg<CLK_CONF_SPEC>
0x54 - I2C CLK configuration register
sourcepub fn comd0(&self) -> &Reg<COMD0_SPEC>
pub fn comd0(&self) -> &Reg<COMD0_SPEC>
0x58 - I2C command register 0
sourcepub fn comd1(&self) -> &Reg<COMD1_SPEC>
pub fn comd1(&self) -> &Reg<COMD1_SPEC>
0x5c - I2C command register 1
sourcepub fn comd2(&self) -> &Reg<COMD2_SPEC>
pub fn comd2(&self) -> &Reg<COMD2_SPEC>
0x60 - I2C command register 2
sourcepub fn comd3(&self) -> &Reg<COMD3_SPEC>
pub fn comd3(&self) -> &Reg<COMD3_SPEC>
0x64 - I2C command register 3
sourcepub fn comd4(&self) -> &Reg<COMD4_SPEC>
pub fn comd4(&self) -> &Reg<COMD4_SPEC>
0x68 - I2C command register 4
sourcepub fn comd5(&self) -> &Reg<COMD5_SPEC>
pub fn comd5(&self) -> &Reg<COMD5_SPEC>
0x6c - I2C command register 5
sourcepub fn comd6(&self) -> &Reg<COMD6_SPEC>
pub fn comd6(&self) -> &Reg<COMD6_SPEC>
0x70 - I2C command register 6
sourcepub fn comd7(&self) -> &Reg<COMD7_SPEC>
pub fn comd7(&self) -> &Reg<COMD7_SPEC>
0x74 - I2C command register 7
sourcepub fn scl_st_time_out(&self) -> &Reg<SCL_ST_TIME_OUT_SPEC>
pub fn scl_st_time_out(&self) -> &Reg<SCL_ST_TIME_OUT_SPEC>
0x78 - SCL status time out register
sourcepub fn scl_main_st_time_out(&self) -> &Reg<SCL_MAIN_ST_TIME_OUT_SPEC>
pub fn scl_main_st_time_out(&self) -> &Reg<SCL_MAIN_ST_TIME_OUT_SPEC>
0x7c - SCL main status time out register
sourcepub fn scl_sp_conf(&self) -> &Reg<SCL_SP_CONF_SPEC>
pub fn scl_sp_conf(&self) -> &Reg<SCL_SP_CONF_SPEC>
0x80 - Power configuration register
sourcepub fn txfifo_start_addr(&self) -> &Reg<TXFIFO_START_ADDR_SPEC>
pub fn txfifo_start_addr(&self) -> &Reg<TXFIFO_START_ADDR_SPEC>
0x100 - I2C TXFIFO base address register
sourcepub fn rxfifo_start_addr(&self) -> &Reg<RXFIFO_START_ADDR_SPEC>
pub fn rxfifo_start_addr(&self) -> &Reg<RXFIFO_START_ADDR_SPEC>
0x180 - I2C RXFIFO base address register