#[non_exhaustive]pub struct OTP_DEBUG<'a> { /* private fields */ }unstable only.Expand description
OTP_DEBUG peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl OTP_DEBUG<'_>
impl OTP_DEBUG<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourceimpl OTP_DEBUG<'_>
impl OTP_DEBUG<'_>
Sourcepub const PTR: *const <OTP_DEBUG as Deref>::Target = pac::OTP_DEBUG::PTR
pub const PTR: *const <OTP_DEBUG as Deref>::Target = pac::OTP_DEBUG::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <OTP_DEBUG as Deref>::Target
pub const fn ptr() -> *const <OTP_DEBUG as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <OTP_DEBUG as Deref>::Target
pub fn regs<'a>() -> &'a <OTP_DEBUG as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<OTP_DEBUG as Deref>::Target
pub fn register_block(&self) -> &<OTP_DEBUG as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.