esp_hal::peripherals

Struct PCNT

pub struct PCNT { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl PCNT

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl PCNT

pub const PTR: *const <PCNT as Deref>::Target = {0x60012000 as *const <esp32c6::PCNT as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <PCNT as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn unit(&self, n: usize) -> &UNIT

0x00..0x30 - Cluster UNIT%s, containing U?_CONF0, U?_CONF1, U?_CONF2

pub fn unit_iter(&self) -> impl Iterator<Item = &UNIT>

Iterator for array of: 0x00..0x30 - Cluster UNIT%s, containing U?_CONF0, U?_CONF1, U?_CONF2

pub fn u_cnt(&self, n: usize) -> &Reg<U_CNT_SPEC>

0x30..0x40 - Counter value for unit %s

pub fn u_cnt_iter(&self) -> impl Iterator<Item = &Reg<U_CNT_SPEC>>

Iterator for array of: 0x30..0x40 - Counter value for unit %s

pub fn u0_cnt(&self) -> &Reg<U_CNT_SPEC>

0x30 - Counter value for unit 0

pub fn u1_cnt(&self) -> &Reg<U_CNT_SPEC>

0x34 - Counter value for unit 1

pub fn u2_cnt(&self) -> &Reg<U_CNT_SPEC>

0x38 - Counter value for unit 2

pub fn u3_cnt(&self) -> &Reg<U_CNT_SPEC>

0x3c - Counter value for unit 3

pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>

0x40 - Interrupt raw status register

pub fn int_st(&self) -> &Reg<INT_ST_SPEC>

0x44 - Interrupt status register

pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>

0x48 - Interrupt enable register

pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>

0x4c - Interrupt clear register

pub fn u_status(&self, n: usize) -> &Reg<U_STATUS_SPEC>

0x50..0x60 - PNCT UNIT%s status register

pub fn u_status_iter(&self) -> impl Iterator<Item = &Reg<U_STATUS_SPEC>>

Iterator for array of: 0x50..0x60 - PNCT UNIT%s status register

pub fn u0_status(&self) -> &Reg<U_STATUS_SPEC>

0x50 - PNCT UNIT0 status register

pub fn u1_status(&self) -> &Reg<U_STATUS_SPEC>

0x54 - PNCT UNIT1 status register

pub fn u2_status(&self) -> &Reg<U_STATUS_SPEC>

0x58 - PNCT UNIT2 status register

pub fn u3_status(&self) -> &Reg<U_STATUS_SPEC>

0x5c - PNCT UNIT3 status register

pub fn ctrl(&self) -> &Reg<CTRL_SPEC>

0x60 - Control register for all counters

pub fn date(&self) -> &Reg<DATE_SPEC>

0xfc - PCNT version control register