Struct esp_hal::peripherals::RSA
source · pub struct RSA { /* private fields */ }Implementations
sourceimpl RSA
impl RSA
sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Methods from Deref<Target = RegisterBlock>
sourcepub fn m_mem(&self, n: usize) -> &Reg<M_MEM_SPEC>
pub fn m_mem(&self, n: usize) -> &Reg<M_MEM_SPEC>
0x00..0x180 - The memory that stores M
sourcepub fn m_mem_iter(&self) -> impl Iterator<Item = &Reg<M_MEM_SPEC>>
pub fn m_mem_iter(&self) -> impl Iterator<Item = &Reg<M_MEM_SPEC>>
Iterator for array of: 0x00..0x180 - The memory that stores M
sourcepub fn z_mem(&self, n: usize) -> &Reg<Z_MEM_SPEC>
pub fn z_mem(&self, n: usize) -> &Reg<Z_MEM_SPEC>
0x200..0x380 - The memory that stores Z
sourcepub fn z_mem_iter(&self) -> impl Iterator<Item = &Reg<Z_MEM_SPEC>>
pub fn z_mem_iter(&self) -> impl Iterator<Item = &Reg<Z_MEM_SPEC>>
Iterator for array of: 0x200..0x380 - The memory that stores Z
sourcepub fn y_mem(&self, n: usize) -> &Reg<Y_MEM_SPEC>
pub fn y_mem(&self, n: usize) -> &Reg<Y_MEM_SPEC>
0x400..0x580 - The memory that stores Y
sourcepub fn y_mem_iter(&self) -> impl Iterator<Item = &Reg<Y_MEM_SPEC>>
pub fn y_mem_iter(&self) -> impl Iterator<Item = &Reg<Y_MEM_SPEC>>
Iterator for array of: 0x400..0x580 - The memory that stores Y
sourcepub fn x_mem(&self, n: usize) -> &Reg<X_MEM_SPEC>
pub fn x_mem(&self, n: usize) -> &Reg<X_MEM_SPEC>
0x600..0x780 - The memory that stores X
sourcepub fn x_mem_iter(&self) -> impl Iterator<Item = &Reg<X_MEM_SPEC>>
pub fn x_mem_iter(&self) -> impl Iterator<Item = &Reg<X_MEM_SPEC>>
Iterator for array of: 0x600..0x780 - The memory that stores X
sourcepub fn m_prime(&self) -> &Reg<M_PRIME_SPEC>
pub fn m_prime(&self) -> &Reg<M_PRIME_SPEC>
0x800 - RSA M_prime register
sourcepub fn query_clean(&self) -> &Reg<QUERY_CLEAN_SPEC>
pub fn query_clean(&self) -> &Reg<QUERY_CLEAN_SPEC>
0x808 - RSA query clean register
sourcepub fn set_start_modexp(&self) -> &Reg<SET_START_MODEXP_SPEC>
pub fn set_start_modexp(&self) -> &Reg<SET_START_MODEXP_SPEC>
0x80c - RSA modular exponentiation trigger register.
sourcepub fn set_start_modmult(&self) -> &Reg<SET_START_MODMULT_SPEC>
pub fn set_start_modmult(&self) -> &Reg<SET_START_MODMULT_SPEC>
0x810 - RSA modular multiplication trigger register.
sourcepub fn set_start_mult(&self) -> &Reg<SET_START_MULT_SPEC>
pub fn set_start_mult(&self) -> &Reg<SET_START_MULT_SPEC>
0x814 - RSA normal multiplication trigger register.
sourcepub fn query_idle(&self) -> &Reg<QUERY_IDLE_SPEC>
pub fn query_idle(&self) -> &Reg<QUERY_IDLE_SPEC>
0x818 - RSA query idle register
sourcepub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>
pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>
0x81c - RSA interrupt clear register
sourcepub fn constant_time(&self) -> &Reg<CONSTANT_TIME_SPEC>
pub fn constant_time(&self) -> &Reg<CONSTANT_TIME_SPEC>
0x820 - RSA constant time option register
sourcepub fn search_enable(&self) -> &Reg<SEARCH_ENABLE_SPEC>
pub fn search_enable(&self) -> &Reg<SEARCH_ENABLE_SPEC>
0x824 - RSA search option
sourcepub fn search_pos(&self) -> &Reg<SEARCH_POS_SPEC>
pub fn search_pos(&self) -> &Reg<SEARCH_POS_SPEC>
0x828 - RSA search position configure register
sourcepub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>
pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>
0x82c - RSA interrupt enable register