pub struct SHA { /* private fields */ }Expand description
Represents a virtual peripheral with no associated hardware.
This struct is generated by the create_peripheral! macro when the peripheral
is defined as virtual.
Implementations
Methods from Deref<Target = RegisterBlock>
Sourcepub fn t_string(&self) -> &Reg<T_STRING_SPEC>
pub fn t_string(&self) -> &Reg<T_STRING_SPEC>
0x04 - SHA 512/t configuration register 0.
Sourcepub fn t_length(&self) -> &Reg<T_LENGTH_SPEC>
pub fn t_length(&self) -> &Reg<T_LENGTH_SPEC>
0x08 - SHA 512/t configuration register 1.
Sourcepub fn dma_block_num(&self) -> &Reg<DMA_BLOCK_NUM_SPEC>
pub fn dma_block_num(&self) -> &Reg<DMA_BLOCK_NUM_SPEC>
0x0c - DMA configuration register 0.
Sourcepub fn start(&self) -> &Reg<START_SPEC>
pub fn start(&self) -> &Reg<START_SPEC>
0x10 - Typical SHA configuration register 0.
Sourcepub fn continue_(&self) -> &Reg<CONTINUE_SPEC>
pub fn continue_(&self) -> &Reg<CONTINUE_SPEC>
0x14 - Typical SHA configuration register 1.
Sourcepub fn dma_start(&self) -> &Reg<DMA_START_SPEC>
pub fn dma_start(&self) -> &Reg<DMA_START_SPEC>
0x1c - DMA configuration register 1.
Sourcepub fn dma_continue(&self) -> &Reg<DMA_CONTINUE_SPEC>
pub fn dma_continue(&self) -> &Reg<DMA_CONTINUE_SPEC>
0x20 - DMA configuration register 2.
Sourcepub fn clear_irq(&self) -> &Reg<CLEAR_IRQ_SPEC>
pub fn clear_irq(&self) -> &Reg<CLEAR_IRQ_SPEC>
0x24 - Interrupt clear register.
Sourcepub fn irq_ena(&self) -> &Reg<IRQ_ENA_SPEC>
pub fn irq_ena(&self) -> &Reg<IRQ_ENA_SPEC>
0x28 - Interrupt enable register.
Sourcepub fn h_mem(&self, n: usize) -> &Reg<H_MEM_SPEC>
pub fn h_mem(&self, n: usize) -> &Reg<H_MEM_SPEC>
0x40..0x60 - Sha H memory which contains intermediate hash or finial hash.
Sourcepub fn h_mem_iter(&self) -> impl Iterator<Item = &Reg<H_MEM_SPEC>>
pub fn h_mem_iter(&self) -> impl Iterator<Item = &Reg<H_MEM_SPEC>>
Iterator for array of: 0x40..0x60 - Sha H memory which contains intermediate hash or finial hash.
Sourcepub fn m_mem(&self, n: usize) -> &Reg<M_MEM_SPEC>
pub fn m_mem(&self, n: usize) -> &Reg<M_MEM_SPEC>
0x80..0xc0 - Sha M memory which contains message.
Sourcepub fn m_mem_iter(&self) -> impl Iterator<Item = &Reg<M_MEM_SPEC>>
pub fn m_mem_iter(&self) -> impl Iterator<Item = &Reg<M_MEM_SPEC>>
Iterator for array of: 0x80..0xc0 - Sha M memory which contains message.