esp_hal::peripherals

Struct SOC_ETM

pub struct SOC_ETM { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl SOC_ETM

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl SOC_ETM

pub const PTR: *const <SOC_ETM as Deref>::Target = {0x60013000 as *const <esp32c6::SOC_ETM as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <SOC_ETM as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn ch_ena_ad0(&self) -> &Reg<CH_ENA_AD0_SPEC>

0x00 - channel enable register

pub fn ch_ena_ad0_set(&self) -> &Reg<CH_ENA_AD0_SET_SPEC>

0x04 - channel enable set register

pub fn ch_ena_ad0_clr(&self) -> &Reg<CH_ENA_AD0_CLR_SPEC>

0x08 - channel enable clear register

pub fn ch_ena_ad1(&self) -> &Reg<CH_ENA_AD1_SPEC>

0x0c - channel enable register

pub fn ch_ena_ad1_set(&self) -> &Reg<CH_ENA_AD1_SET_SPEC>

0x10 - channel enable set register

pub fn ch_ena_ad1_clr(&self) -> &Reg<CH_ENA_AD1_CLR_SPEC>

0x14 - channel enable clear register

pub fn ch(&self, n: usize) -> &CH

0x18..0x1a8 - Cluster CH%s, containing CH*_EVT_ID, CH*_TASK_ID

pub fn ch_iter(&self) -> impl Iterator<Item = &CH>

Iterator for array of: 0x18..0x1a8 - Cluster CH%s, containing CH*_EVT_ID, CH*_TASK_ID

pub fn clk_en(&self) -> &Reg<CLK_EN_SPEC>

0x1a8 - etm clock enable register

pub fn date(&self) -> &Reg<DATE_SPEC>

0x1ac - etm date register