esp_hal::peripherals

Struct SPI1

pub struct SPI1 { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl SPI1

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl SPI1

pub const PTR: *const <SPI1 as Deref>::Target = {0x60003000 as *const <esp32c6::SPI1 as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <SPI1 as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn cmd(&self) -> &Reg<CMD_SPEC>

0x00 - SPI1 memory command register

pub fn addr(&self) -> &Reg<ADDR_SPEC>

0x04 - SPI1 address register

pub fn ctrl(&self) -> &Reg<CTRL_SPEC>

0x08 - SPI1 control register.

pub fn ctrl1(&self) -> &Reg<CTRL1_SPEC>

0x0c - SPI1 control1 register.

pub fn ctrl2(&self) -> &Reg<CTRL2_SPEC>

0x10 - SPI1 control2 register.

pub fn clock(&self) -> &Reg<CLOCK_SPEC>

0x14 - SPI1 clock division control register.

pub fn user(&self) -> &Reg<USER_SPEC>

0x18 - SPI1 user register.

pub fn user1(&self) -> &Reg<USER1_SPEC>

0x1c - SPI1 user1 register.

pub fn user2(&self) -> &Reg<USER2_SPEC>

0x20 - SPI1 user2 register.

pub fn mosi_dlen(&self) -> &Reg<MOSI_DLEN_SPEC>

0x24 - SPI1 send data bit length control register.

pub fn miso_dlen(&self) -> &Reg<MISO_DLEN_SPEC>

0x28 - SPI1 receive data bit length control register.

pub fn rd_status(&self) -> &Reg<RD_STATUS_SPEC>

0x2c - SPI1 status register.

pub fn misc(&self) -> &Reg<MISC_SPEC>

0x34 - SPI1 misc register

pub fn tx_crc(&self) -> &Reg<TX_CRC_SPEC>

0x38 - SPI1 TX CRC data register.

pub fn cache_fctrl(&self) -> &Reg<CACHE_FCTRL_SPEC>

0x3c - SPI1 bit mode control register.

pub fn w(&self, n: usize) -> &Reg<W_SPEC>

0x58..0x98 - SPI1 memory data buffer%s

pub fn w_iter(&self) -> impl Iterator<Item = &Reg<W_SPEC>>

Iterator for array of: 0x58..0x98 - SPI1 memory data buffer%s

pub fn flash_waiti_ctrl(&self) -> &Reg<FLASH_WAITI_CTRL_SPEC>

0x98 - SPI1 wait idle control register

pub fn flash_sus_ctrl(&self) -> &Reg<FLASH_SUS_CTRL_SPEC>

0x9c - SPI1 flash suspend control register

pub fn flash_sus_cmd(&self) -> &Reg<FLASH_SUS_CMD_SPEC>

0xa0 - SPI1 flash suspend command register

pub fn sus_status(&self) -> &Reg<SUS_STATUS_SPEC>

0xa4 - SPI1 flash suspend status register

pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>

0xc0 - SPI1 interrupt enable register

pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>

0xc4 - SPI1 interrupt clear register

pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>

0xc8 - SPI1 interrupt raw register

pub fn int_st(&self) -> &Reg<INT_ST_SPEC>

0xcc - SPI1 interrupt status register

pub fn ddr(&self) -> &Reg<DDR_SPEC>

0xd4 - SPI1 DDR control register

pub fn timing_cali(&self) -> &Reg<TIMING_CALI_SPEC>

0x180 - SPI1 timing control register

pub fn clock_gate(&self) -> &Reg<CLOCK_GATE_SPEC>

0x200 - SPI1 clk_gate register

pub fn date(&self) -> &Reg<DATE_SPEC>

0x3fc - Version control register