esp_hal::peripherals

Struct SPI2

pub struct SPI2 { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl SPI2

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl SPI2

pub const PTR: *const <SPI2 as Deref>::Target = {0x60081000 as *const <esp32c6::SPI2 as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <SPI2 as Deref>::Target

Return the pointer to the register block

Source

impl SPI2

pub fn bind_spi2_interrupt(&mut self, handler: unsafe extern "C" fn())

Binds an interrupt handler to the corresponding interrupt for this peripheral.

Methods from Deref<Target = RegisterBlock>

pub fn cmd(&self) -> &Reg<CMD_SPEC>

0x00 - Command control register

pub fn addr(&self) -> &Reg<ADDR_SPEC>

0x04 - Address value register

pub fn ctrl(&self) -> &Reg<CTRL_SPEC>

0x08 - SPI control register

pub fn clock(&self) -> &Reg<CLOCK_SPEC>

0x0c - SPI clock control register

pub fn user(&self) -> &Reg<USER_SPEC>

0x10 - SPI USER control register

pub fn user1(&self) -> &Reg<USER1_SPEC>

0x14 - SPI USER control register 1

pub fn user2(&self) -> &Reg<USER2_SPEC>

0x18 - SPI USER control register 2

pub fn ms_dlen(&self) -> &Reg<MS_DLEN_SPEC>

0x1c - SPI data bit length control register

pub fn misc(&self) -> &Reg<MISC_SPEC>

0x20 - SPI misc register

pub fn din_mode(&self) -> &Reg<DIN_MODE_SPEC>

0x24 - SPI input delay mode configuration

pub fn din_num(&self) -> &Reg<DIN_NUM_SPEC>

0x28 - SPI input delay number configuration

pub fn dout_mode(&self) -> &Reg<DOUT_MODE_SPEC>

0x2c - SPI output delay mode configuration

pub fn dma_conf(&self) -> &Reg<DMA_CONF_SPEC>

0x30 - SPI DMA control register

pub fn dma_int_ena(&self) -> &Reg<DMA_INT_ENA_SPEC>

0x34 - SPI interrupt enable register

pub fn dma_int_clr(&self) -> &Reg<DMA_INT_CLR_SPEC>

0x38 - SPI interrupt clear register

pub fn dma_int_raw(&self) -> &Reg<DMA_INT_RAW_SPEC>

0x3c - SPI interrupt raw register

pub fn dma_int_st(&self) -> &Reg<DMA_INT_ST_SPEC>

0x40 - SPI interrupt status register

pub fn dma_int_set(&self) -> &Reg<DMA_INT_SET_SPEC>

0x44 - SPI interrupt software set register

pub fn w(&self, n: usize) -> &Reg<W_SPEC>

0x98..0xd8 - SPI CPU-controlled buffer%s

pub fn w_iter(&self) -> impl Iterator<Item = &Reg<W_SPEC>>

Iterator for array of: 0x98..0xd8 - SPI CPU-controlled buffer%s

pub fn slave(&self) -> &Reg<SLAVE_SPEC>

0xe0 - SPI slave control register

pub fn slave1(&self) -> &Reg<SLAVE1_SPEC>

0xe4 - SPI slave control register 1

pub fn clk_gate(&self) -> &Reg<CLK_GATE_SPEC>

0xe8 - SPI module clock and register clock control

pub fn date(&self) -> &Reg<DATE_SPEC>

0xf0 - Version control