esp_hal::peripherals

Struct SYSTIMER

pub struct SYSTIMER { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl SYSTIMER

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl SYSTIMER

pub const PTR: *const <SYSTIMER as Deref>::Target = {0x6000a000 as *const <esp32c6::SYSTIMER as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <SYSTIMER as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn conf(&self) -> &Reg<CONF_SPEC>

0x00 - Configure system timer clock

pub fn unit_op(&self, n: usize) -> &Reg<UNIT_OP_SPEC>

0x04..0x0c - system timer unit%s value update register

pub fn unit_op_iter(&self) -> impl Iterator<Item = &Reg<UNIT_OP_SPEC>>

Iterator for array of: 0x04..0x0c - system timer unit%s value update register

pub fn unit0_op(&self) -> &Reg<UNIT_OP_SPEC>

0x04 - system timer unit0 value update register

pub fn unit1_op(&self) -> &Reg<UNIT_OP_SPEC>

0x08 - system timer unit1 value update register

pub fn unitload(&self, n: usize) -> &UNITLOAD

0x0c..0x1c - Cluster UNIT%sLOAD, containing UNIT?_LOAD_HI, UNIT?_LOAD_LO

pub fn unitload_iter(&self) -> impl Iterator<Item = &UNITLOAD>

Iterator for array of: 0x0c..0x1c - Cluster UNIT%sLOAD, containing UNIT?_LOAD_HI, UNIT?_LOAD_LO

pub fn unit0load(&self) -> &UNITLOAD

0x0c..0x14 - Cluster UNIT0LOAD, containing UNIT?_LOAD_HI, UNIT?_LOAD_LO

pub fn unit1load(&self) -> &UNITLOAD

0x14..0x1c - Cluster UNIT1LOAD, containing UNIT?_LOAD_HI, UNIT?_LOAD_LO

pub fn trgt(&self, n: usize) -> &TRGT

0x1c..0x34 - Cluster TRGT%s, containing TARGET?_HI, TARGET?_LO

pub fn trgt_iter(&self) -> impl Iterator<Item = &TRGT>

Iterator for array of: 0x1c..0x34 - Cluster TRGT%s, containing TARGET?_HI, TARGET?_LO

pub fn target_conf(&self, n: usize) -> &Reg<TARGET_CONF_SPEC>

0x34..0x40 - system timer comp%s target mode register

pub fn target_conf_iter(&self) -> impl Iterator<Item = &Reg<TARGET_CONF_SPEC>>

Iterator for array of: 0x34..0x40 - system timer comp%s target mode register

pub fn target0_conf(&self) -> &Reg<TARGET_CONF_SPEC>

0x34 - system timer comp0 target mode register

pub fn target1_conf(&self) -> &Reg<TARGET_CONF_SPEC>

0x38 - system timer comp1 target mode register

pub fn target2_conf(&self) -> &Reg<TARGET_CONF_SPEC>

0x3c - system timer comp2 target mode register

pub fn unit_value(&self, n: usize) -> &UNIT_VALUE

0x40..0x50 - Cluster UNIT%s_VALUE, containing UNIT?_VALUE_HI, UNIT?_VALUE_LO

pub fn unit_value_iter(&self) -> impl Iterator<Item = &UNIT_VALUE>

Iterator for array of: 0x40..0x50 - Cluster UNIT%s_VALUE, containing UNIT?_VALUE_HI, UNIT?_VALUE_LO

pub fn unit0_value(&self) -> &UNIT_VALUE

0x40..0x48 - Cluster UNIT0_VALUE, containing UNIT?_VALUE_HI, UNIT?_VALUE_LO

pub fn unit1_value(&self) -> &UNIT_VALUE

0x48..0x50 - Cluster UNIT1_VALUE, containing UNIT?_VALUE_HI, UNIT?_VALUE_LO

pub fn comp_load(&self, n: usize) -> &Reg<COMP_LOAD_SPEC>

0x50..0x5c - system timer comp%s conf sync register

pub fn comp_load_iter(&self) -> impl Iterator<Item = &Reg<COMP_LOAD_SPEC>>

Iterator for array of: 0x50..0x5c - system timer comp%s conf sync register

pub fn comp0_load(&self) -> &Reg<COMP_LOAD_SPEC>

0x50 - system timer comp0 conf sync register

pub fn comp1_load(&self) -> &Reg<COMP_LOAD_SPEC>

0x54 - system timer comp1 conf sync register

pub fn comp2_load(&self) -> &Reg<COMP_LOAD_SPEC>

0x58 - system timer comp2 conf sync register

pub fn unit_load(&self, n: usize) -> &Reg<UNIT_LOAD_SPEC>

0x5c..0x64 - system timer unit%s conf sync register

pub fn unit_load_iter(&self) -> impl Iterator<Item = &Reg<UNIT_LOAD_SPEC>>

Iterator for array of: 0x5c..0x64 - system timer unit%s conf sync register

pub fn unit0_load(&self) -> &Reg<UNIT_LOAD_SPEC>

0x5c - system timer unit0 conf sync register

pub fn unit1_load(&self) -> &Reg<UNIT_LOAD_SPEC>

0x60 - system timer unit1 conf sync register

pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>

0x64 - systimer interrupt enable register

pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>

0x68 - systimer interrupt raw register

pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>

0x6c - systimer interrupt clear register

pub fn int_st(&self) -> &Reg<INT_ST_SPEC>

0x70 - systimer interrupt status register

pub fn real_target(&self, n: usize) -> &REAL_TARGET

0x74..0x8c - Cluster REAL_TARGET%s, containing REAL_TARGET?_LO, REAL_TARGET?_HI

pub fn real_target_iter(&self) -> impl Iterator<Item = &REAL_TARGET>

Iterator for array of: 0x74..0x8c - Cluster REAL_TARGET%s, containing REAL_TARGET?_LO, REAL_TARGET?_HI

pub fn date(&self) -> &Reg<DATE_SPEC>

0xfc - system timer version control register