esp_hal::peripherals

Struct TIMG1

pub struct TIMG1 { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl TIMG1

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl TIMG1

pub const PTR: *const <TIMG1 as Deref>::Target = {0x60009000 as *const <esp32c6::TIMG1 as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <TIMG1 as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn t(&self, n: usize) -> &T

0x00..0x24 - Cluster T%s, containing T?CONFIG, T?LO, T?HI, T?UPDATE, T?ALARMLO, T?ALARMHI, T?LOADLO, T?LOADHI, T?LOAD

pub fn t_iter(&self) -> impl Iterator<Item = &T>

Iterator for array of: 0x00..0x24 - Cluster T%s, containing T?CONFIG, T?LO, T?HI, T?UPDATE, T?ALARMLO, T?ALARMHI, T?LOADLO, T?LOADHI, T?LOAD

pub fn wdtconfig0(&self) -> &Reg<WDTCONFIG0_SPEC>

0x48 - Watchdog timer configuration register

pub fn wdtconfig1(&self) -> &Reg<WDTCONFIG1_SPEC>

0x4c - Watchdog timer prescaler register

pub fn wdtconfig2(&self) -> &Reg<WDTCONFIG2_SPEC>

0x50 - Watchdog timer stage 0 timeout value

pub fn wdtconfig3(&self) -> &Reg<WDTCONFIG3_SPEC>

0x54 - Watchdog timer stage 1 timeout value

pub fn wdtconfig4(&self) -> &Reg<WDTCONFIG4_SPEC>

0x58 - Watchdog timer stage 2 timeout value

pub fn wdtconfig5(&self) -> &Reg<WDTCONFIG5_SPEC>

0x5c - Watchdog timer stage 3 timeout value

pub fn wdtfeed(&self) -> &Reg<WDTFEED_SPEC>

0x60 - Write to feed the watchdog timer

pub fn wdtwprotect(&self) -> &Reg<WDTWPROTECT_SPEC>

0x64 - Watchdog write protect register

pub fn rtccalicfg(&self) -> &Reg<RTCCALICFG_SPEC>

0x68 - RTC calibration configure register

pub fn rtccalicfg1(&self) -> &Reg<RTCCALICFG1_SPEC>

0x6c - RTC calibration configure1 register

pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>

0x70 - Interrupt enable bits

pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>

0x74 - Raw interrupt status

pub fn int_st(&self) -> &Reg<INT_ST_SPEC>

0x78 - Masked interrupt status

pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>

0x7c - Interrupt clear bits

pub fn rtccalicfg2(&self) -> &Reg<RTCCALICFG2_SPEC>

0x80 - Timer group calibration register

pub fn ntimers_date(&self) -> &Reg<NTIMERS_DATE_SPEC>

0xf8 - Timer version control register

pub fn regclk(&self) -> &Reg<REGCLK_SPEC>

0xfc - Timer group clock gate register