esp_hal::peripherals

Struct UHCI0

pub struct UHCI0 { /* private fields */ }
Represents a virtual peripheral with no associated hardware.

This struct is generated by the create_peripheral! macro when the peripheral is defined as virtual.

Implementations

Source

impl UHCI0

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

Source

impl UHCI0

pub const PTR: *const <UHCI0 as Deref>::Target = {0x60005000 as *const <esp32c6::UHCI0 as core::ops::Deref>::Target}

Pointer to the register block

pub const fn ptr() -> *const <UHCI0 as Deref>::Target

Return the pointer to the register block

Methods from Deref<Target = RegisterBlock>

pub fn conf0(&self) -> &Reg<CONF0_SPEC>

0x00 - UHCI Configuration Register0

pub fn int_raw(&self) -> &Reg<INT_RAW_SPEC>

0x04 - UHCI Interrupt Raw Register

pub fn int_st(&self) -> &Reg<INT_ST_SPEC>

0x08 - UHCI Interrupt Status Register

pub fn int_ena(&self) -> &Reg<INT_ENA_SPEC>

0x0c - UHCI Interrupt Enable Register

pub fn int_clr(&self) -> &Reg<INT_CLR_SPEC>

0x10 - UHCI Interrupt Clear Register

pub fn conf1(&self) -> &Reg<CONF1_SPEC>

0x14 - UHCI Configuration Register1

pub fn state0(&self) -> &Reg<STATE0_SPEC>

0x18 - UHCI Receive Status Register

pub fn state1(&self) -> &Reg<STATE1_SPEC>

0x1c - UHCI Transmit Status Register

pub fn escape_conf(&self) -> &Reg<ESCAPE_CONF_SPEC>

0x20 - UHCI Escapes Configuration Register0

pub fn hung_conf(&self) -> &Reg<HUNG_CONF_SPEC>

0x24 - UHCI Hung Configuration Register0

pub fn ack_num(&self) -> &Reg<ACK_NUM_SPEC>

0x28 - UHCI Ack Value Configuration Register0

pub fn rx_head(&self) -> &Reg<RX_HEAD_SPEC>

0x2c - UHCI Head Register

pub fn quick_sent(&self) -> &Reg<QUICK_SENT_SPEC>

0x30 - UCHI Quick send Register

pub fn reg_q(&self, n: usize) -> &REG_Q

0x34..0x6c - Cluster REG_Q%s, containing REG_Q?_WORD0, REG_Q?_WORD1

pub fn reg_q_iter(&self) -> impl Iterator<Item = &REG_Q>

Iterator for array of: 0x34..0x6c - Cluster REG_Q%s, containing REG_Q?_WORD0, REG_Q?_WORD1

pub fn esc_conf(&self, n: usize) -> &Reg<ESC_CONF_SPEC>

0x6c..0x7c - UHCI Escapes Sequence Configuration Register%s

pub fn esc_conf_iter(&self) -> impl Iterator<Item = &Reg<ESC_CONF_SPEC>>

Iterator for array of: 0x6c..0x7c - UHCI Escapes Sequence Configuration Register%s

pub fn pkt_thres(&self) -> &Reg<PKT_THRES_SPEC>

0x7c - UCHI Packet Length Configuration Register

pub fn date(&self) -> &Reg<DATE_SPEC>

0x80 - UHCI Version Register