#[non_exhaustive]pub struct USB_DEVICE<'a> { /* private fields */ }unstable only.Expand description
USB_DEVICE peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl USB_DEVICE<'_>
impl USB_DEVICE<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> USB_DEVICE<'_>
pub fn reborrow(&mut self) -> USB_DEVICE<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after the driver that consumes it is dropped.
Sourcepub fn bind_peri_interrupt(&self, handler: InterruptHandler)
pub fn bind_peri_interrupt(&self, handler: InterruptHandler)
Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn enable_peri_interrupt(&self, priority: Priority)
pub fn enable_peri_interrupt(&self, priority: Priority)
Enables the USB_DEVICE peripheral interrupt on the given priority level.
A suitable interrupt handler must be set up before the first interrupt
is triggered; otherwise the default handler panics.
To set up an interrupt handler, use Self::bind_peri_interrupt or create a function that has the same (non-mangled) name as the interrupt to handle.
Examples
use esp_hal::interrupt::Priority;
#[unsafe(no_mangle)]
unsafe extern "C" fn USB_DEVICE() {
// do something
}
peripherals.USB_DEVICE.enable_peri_interrupt(Priority::Priority1);
peripherals.USB_DEVICE.disable_peri_interrupt_on_all_cores();Sourcepub fn disable_peri_interrupt(&self)
pub fn disable_peri_interrupt(&self)
Disables the USB_DEVICE peripheral interrupt handler on the current CPU core.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn disable_peri_interrupt_on_all_cores(&self)
pub fn disable_peri_interrupt_on_all_cores(&self)
Disables the USB_DEVICE peripheral interrupt handler on all cores.
Sourceimpl USB_DEVICE<'_>
impl USB_DEVICE<'_>
Sourcepub const PTR: *const <USB_DEVICE as Deref>::Target = pac::USB_DEVICE::PTR
pub const PTR: *const <USB_DEVICE as Deref>::Target = pac::USB_DEVICE::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <USB_DEVICE as Deref>::Target
pub const fn ptr() -> *const <USB_DEVICE as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <USB_DEVICE as Deref>::Target
pub fn regs<'a>() -> &'a <USB_DEVICE as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<USB_DEVICE as Deref>::Target
pub fn register_block(&self) -> &<USB_DEVICE as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.