PulseCode

Struct PulseCode 

#[repr(transparent)]
pub struct PulseCode(pub u32);
Convenience newtype to work with pulse codes.

A PulseCode is represented as u32, with fields laid out as follows:

Bit 31Bits 30-16Bit 15Bits 14-0
level2length2level1length1

Here, level1 / length1 correspond to the signal that is send/received first, and the signal with level2 / length2 is send/received afterwards.

If length1 or length2 are zero, this implies an end marker and transmission will stop with the corresponding signal.

Tuple Fields

0: u32

Implementations

Source

impl PulseCode

pub const MAX_LEN: u16 = 32767

Maximum value for the length1 and length2 fields.

pub const fn new( level1: Level, length1: u16, level2: Level, length2: u16, ) -> Self

Create a new instance.

Panics if length1 or length2 exceed the maximum representable range.

pub const fn new_clamped( level1: Level, length1: u16, level2: Level, length2: u16, ) -> Self

Create a new instance.

If length1 or length2 exceed the maximum representable range, they will be clamped to Self::MAX_LEN.

pub fn try_new( level1: Level, length1: impl TryInto<u16>, level2: Level, length2: impl TryInto<u16>, ) -> Option<Self>

Create a new instance, attempting to convert lengths to u16 first.

This is slightly more convenient when passing in longer integers (e.g. u32) resulting from a preceding calculation.

If length1 or length2 fail to convert to u16 or exceed the maximum representable range, this will return None.

pub const unsafe fn new_unchecked( level1: Level, length1: u16, level2: Level, length2: u16, ) -> Self

Create a new instance without checking that code lengths are in range.

Safety

length1 and length2 must be 15-bit wide, i.e. their MSB must be cleared.

pub const fn end_marker() -> Self

Create a new instance that is an end marker with Level::Low.

This corresponds to the all-zero PulseCode, i.e. with both level and length fields set to zero, equivalent to (but more semantic than) PulseCode::from(0u32) and PulseCode::default().

pub fn reset(&mut self)

Set all levels and lengths to 0.

In other words, assigns the value of PulseCode::end_marker() to self.

pub const fn level1(self) -> Level

Logical output level in the first pulse code interval

pub const fn level2(self) -> Level

Logical output level in the second pulse code interval

pub const fn length1(self) -> u16

Length of the first pulse code interval (in clock cycles)

pub const fn length2(self) -> u16

Length of the second pulse code interval (in clock cycles)

pub const fn with_level1(self, level: Level) -> Self

Set level1 and return the modified PulseCode.

pub const fn with_level2(self, level: Level) -> Self

Set level2 and return the modified PulseCode.

pub const fn with_length1(self, length: u16) -> Option<Self>

Set length1 and return the modified PulseCode.

Returns None if length exceeds the representable range.

pub const fn with_length2(self, length: u16) -> Option<Self>

Set length2 and return the modified PulseCode.

Returns None if length exceeds the representable range.

pub const fn is_end_marker(self) -> bool

Return whether this pulse code contains an end marker.

Equivalent to self.length1() == 0 || self.length2() == 0.