pub struct Rng { /* private fields */ }Expand description
Random number generator driver
Implementations
Sourceimpl Rng
impl Rng
Sourcepub fn new(_rng: impl Peripheral<P = RNG>) -> Self
pub fn new(_rng: impl Peripheral<P = RNG>) -> Self
Create a new random number generator instance
Sourcepub fn read(&mut self, buffer: &mut [u8])
pub fn read(&mut self, buffer: &mut [u8])
Reads enough bytes from hardware random number generator to fill
buffer.
If any error is encountered then this function immediately returns. The contents of buf are unspecified in this case.
If this function returns an error, it is unspecified how many bytes it has read, but it will never read more than would be necessary to completely fill the buffer.