SocResetReason

Enum SocResetReason 

pub enum SocResetReason {
Show 18 variants ChipPowerOn = 1, CoreSw = 3, CoreDeepSleep = 5, CoreSDIO = 6, CoreMwdt0 = 7, CoreMwdt1 = 8, CoreRtcWdt = 9, Cpu0Mwdt0 = 11, Cpu0Sw = 12, Cpu0RtcWdt = 13, SysBrownOut = 15, SysRtcWdt = 16, Cpu0Mwdt1 = 17, SysSuperWdt = 18, CoreEfuseCrc = 20, CoreUsbUart = 21, CoreUsbJtag = 22, Cpu0JtagCpu = 24,
}
Available on crate feature unstable only.
SOC Reset Reason.

Variants



ChipPowerOn = 1

Power on reset

In ESP-IDF this value (0x01) can also be ChipBrownOut or ChipSuperWdt, however that is not really compatible with Rust-style enums.



CoreSw = 3

Software resets the digital core by RTC_CNTL_SW_SYS_RST



CoreDeepSleep = 5

Deep sleep reset the digital core



CoreSDIO = 6

SDIO Core reset



CoreMwdt0 = 7

Main watch dog 0 resets digital core



CoreMwdt1 = 8

Main watch dog 1 resets digital core



CoreRtcWdt = 9

RTC watch dog resets digital core



Cpu0Mwdt0 = 11

Main watch dog 0 resets CPU 0



Cpu0Sw = 12

Software resets CPU 0 by RTC_CNTL_SW_PROCPU_RST



Cpu0RtcWdt = 13

RTC watch dog resets CPU 0



SysBrownOut = 15

VDD voltage is not stable and resets the digital core



SysRtcWdt = 16

RTC watch dog resets digital core and rtc module



Cpu0Mwdt1 = 17

Main watch dog 1 resets CPU 0



SysSuperWdt = 18

Super watch dog resets the digital core and rtc module



CoreEfuseCrc = 20

eFuse CRC error resets the digital core



CoreUsbUart = 21

USB UART resets the digital core



CoreUsbJtag = 22

USB JTAG resets the digital core



Cpu0JtagCpu = 24

JTAG resets CPU

Implementations

Source

impl SocResetReason

pub const fn from_repr(discriminant: usize) -> Option<SocResetReason>

Try to create Self from the raw representation