#[non_exhaustive]pub struct WakeLock;unstable only.Expand description
A guard that prevents the system from entering automatic light sleep.
While at least one WakeLock is held, WakeLock::is_active returns true
and the auto-lightsleep idle hook will not put the chip to sleep. The lock is
released when the guard is dropped.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations