pub struct OneShotTimer<'d, T> { /* private fields */ }Expand description
A one-shot timer.
Implementations
Sourceimpl<'d, T> OneShotTimer<'d, T>where
T: Timer,
impl<'d, T> OneShotTimer<'d, T>where
T: Timer,
Sourcepub fn new(inner: impl Peripheral<P = T> + 'd) -> Self
pub fn new(inner: impl Peripheral<P = T> + 'd) -> Self
Construct a new instance of OneShotTimer.
Sourcepub fn delay_millis(&self, ms: u32)
pub fn delay_millis(&self, ms: u32)
Pauses execution for at least ms milliseconds.
Sourcepub fn delay_micros(&self, us: u32)
pub fn delay_micros(&self, us: u32)
Pauses execution for at least us microseconds.
Sourcepub fn delay_nanos(&self, ns: u32)
pub fn delay_nanos(&self, ns: u32)
Pauses execution for at least ns nanoseconds.
Sourcepub fn schedule(&mut self, timeout: MicrosDurationU64) -> Result<(), Error>
pub fn schedule(&mut self, timeout: MicrosDurationU64) -> Result<(), Error>
Start counting until the given timeout and raise an interrupt
Sourcepub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
Set the interrupt handler
Note that this will replace any previously set interrupt handler
Sourcepub fn enable_interrupt(&mut self, enable: bool)
pub fn enable_interrupt(&mut self, enable: bool)
Enable listening for interrupts
Sourcepub fn clear_interrupt(&mut self)
pub fn clear_interrupt(&mut self)
Clear the interrupt flag