pub struct Wdt<TG> { /* private fields */ }Expand description
Watchdog timer
Implementations
sourceimpl<TG> Wdt<TG>where
TG: TimerGroupInstance,
impl<TG> Wdt<TG>where
TG: TimerGroupInstance,
Watchdog driver
sourcepub unsafe fn set_wdt_enabled(enabled: bool)
pub unsafe fn set_wdt_enabled(enabled: bool)
Forcibly enable or disable the watchdog timer
Safety
This bypasses the usual ownership rules for the peripheral, so users must take care to ensure that no driver instance is active for the timer.