pub struct Alarm<'d> { /* private fields */ }Expand description
An alarm unit.
Implementations
Sourceimpl Alarm<'_>
impl Alarm<'_>
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> Alarm<'_>
pub fn reborrow(&mut self) -> Alarm<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after dropping the driver that consumes this.
See Peripheral singleton section for more information.