esp_hal::timer::systimer

Struct Alarm

pub struct Alarm<'d, MODE, DM, COMP = AnyComparator<'d>, UNIT = AnyUnit<'d>>
where DM: Mode,
{ /* private fields */ }
A single alarm.

Implementations

Source

impl<'d, T, COMP: Comparator, UNIT: Unit> Alarm<'d, T, Blocking, COMP, UNIT>

pub fn new(comparator: COMP, unit: &FrozenUnit<'d, UNIT>) -> Self

Creates a new alarm from a comparator and unit, in blocking mode.

Source

impl<'d, T, COMP: Comparator, UNIT: Unit> Alarm<'d, T, Async, COMP, UNIT>

pub fn new_async(comparator: COMP, unit: &FrozenUnit<'d, UNIT>) -> Self

Creates a new alarm from a comparator and unit, in async mode.

Source

impl<'d, DM, COMP: Comparator, UNIT: Unit> Alarm<'d, Target, DM, COMP, UNIT>
where DM: Mode,

pub fn set_target(&self, timestamp: u64)

Set the target value of this Alarm

pub fn wait_until(&self, timestamp: u64)

Block waiting until the timer reaches the timestamp

pub fn into_periodic(self) -> Alarm<'d, Periodic, DM, COMP, UNIT>

Converts this Alarm into Periodic mode

Source

impl<'d, DM, COMP: Comparator, UNIT: Unit> Alarm<'d, Periodic, DM, COMP, UNIT>
where DM: Mode,

pub fn set_period(&self, period: MicrosDurationU32)

Set the period of this Alarm

pub fn into_target(self) -> Alarm<'d, Target, DM, COMP, UNIT>

Converts this Alarm into Target mode