pub struct Alarm<'d, MODE, DM, COMP = AnyComparator<'d>, UNIT = AnyUnit<'d>>where
DM: Mode,{ /* private fields */ }Expand description
A single alarm.
Implementations
Sourceimpl<'d, T, COMP: Comparator, UNIT: Unit> Alarm<'d, T, Blocking, COMP, UNIT>
impl<'d, T, COMP: Comparator, UNIT: Unit> Alarm<'d, T, Blocking, COMP, UNIT>
Sourcepub fn new(comparator: COMP, unit: &FrozenUnit<'d, UNIT>) -> Self
pub fn new(comparator: COMP, unit: &FrozenUnit<'d, UNIT>) -> Self
Creates a new alarm from a comparator and unit, in blocking mode.
Sourceimpl<'d, T, COMP: Comparator, UNIT: Unit> Alarm<'d, T, Async, COMP, UNIT>
impl<'d, T, COMP: Comparator, UNIT: Unit> Alarm<'d, T, Async, COMP, UNIT>
Sourcepub fn new_async(comparator: COMP, unit: &FrozenUnit<'d, UNIT>) -> Self
pub fn new_async(comparator: COMP, unit: &FrozenUnit<'d, UNIT>) -> Self
Creates a new alarm from a comparator and unit, in async mode.
Sourceimpl<'d, DM, COMP: Comparator, UNIT: Unit> Alarm<'d, Target, DM, COMP, UNIT>where
DM: Mode,
impl<'d, DM, COMP: Comparator, UNIT: Unit> Alarm<'d, Target, DM, COMP, UNIT>where
DM: Mode,
Sourcepub fn set_target(&self, timestamp: u64)
pub fn set_target(&self, timestamp: u64)
Set the target value of this Alarm
Sourcepub fn wait_until(&self, timestamp: u64)
pub fn wait_until(&self, timestamp: u64)
Block waiting until the timer reaches the timestamp
Sourceimpl<'d, DM, COMP: Comparator, UNIT: Unit> Alarm<'d, Periodic, DM, COMP, UNIT>where
DM: Mode,
impl<'d, DM, COMP: Comparator, UNIT: Unit> Alarm<'d, Periodic, DM, COMP, UNIT>where
DM: Mode,
Sourcepub fn set_period(&self, period: MicrosDurationU32)
pub fn set_period(&self, period: MicrosDurationU32)
Set the period of this Alarm