pub trait DriverMode: Sealed { }Expand description
A marker trait for driver modes.
Different driver modes offer different features and different API. Using this trait as a generic parameter ensures that the driver is initialized in the correct mode.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".