esp_hal::uart

Struct UartRx

pub struct UartRx<'d, M, T = AnyUart> { /* private fields */ }
UART (Receive)

Implementations

Source

impl<'d, M, T> UartRx<'d, M, T>
where T: Instance, M: Mode,

pub fn with_cts( self, cts: impl Peripheral<P = impl PeripheralInput> + 'd, ) -> Self

Configure CTS pin

pub fn apply_config(&mut self, config: &Config) -> Result<(), Error>

Change the configuration.

Note that this also changes the configuration of the TX half.

pub fn read_bytes(&mut self, buf: &mut [u8]) -> Result<(), Error>

Fill a buffer with received bytes

pub fn read_byte(&mut self) -> Result<u8, Error>

Read a byte from the UART

pub fn drain_fifo(&mut self, buf: &mut [u8]) -> usize

Read all available bytes from the RX FIFO into the provided buffer and returns the number of read bytes. Never blocks

Source

impl<'d> UartRx<'d, Blocking>

pub fn new( uart: impl Peripheral<P = impl Instance> + 'd, rx: impl Peripheral<P = impl PeripheralInput> + 'd, ) -> Result<Self, Error>

Create a new UART RX instance in Blocking mode.

pub fn new_with_config( uart: impl Peripheral<P = impl Instance> + 'd, config: Config, rx: impl Peripheral<P = impl PeripheralInput> + 'd, ) -> Result<Self, Error>

Create a new UART RX instance with configuration options in Blocking mode.

Source

impl<'d, T> UartRx<'d, Blocking, T>
where T: Instance,

pub fn new_typed( uart: impl Peripheral<P = T> + 'd, rx: impl Peripheral<P = impl PeripheralInput> + 'd, ) -> Result<Self, Error>

Create a new UART RX instance in Blocking mode.

pub fn new_with_config_typed( uart: impl Peripheral<P = T> + 'd, config: Config, rx: impl Peripheral<P = impl PeripheralInput> + 'd, ) -> Result<Self, Error>

Create a new UART RX instance with configuration options in Blocking mode.

pub fn into_async(self) -> UartRx<'d, Async, T>

Reconfigures the driver to operate in Async mode.

Source

impl<'d, T> UartRx<'d, Async, T>
where T: Instance,

pub fn into_blocking(self) -> UartRx<'d, Blocking, T>

Reconfigures the driver to operate in Blocking mode.

Source

impl<T> UartRx<'_, Async, T>
where T: Instance,

pub async fn read_async(&mut self, buf: &mut [u8]) -> Result<usize, Error>

Read async to buffer slice buf. Waits until at least one byte is in the Rx FiFo and one of the following interrupts occurs:

  • RXFIFO_FULL
  • RXFIFO_OVF
  • AT_CMD_CHAR_DET (only if set_at_cmd was called)
  • RXFIFO_TOUT (only if `set_rx_timeout was called)

The interrupts in question are enabled during the body of this function. The method immediately returns when the interrupt has already occurred before calling this method (e.g. status bit set, but interrupt not enabled)

Params
  • buf buffer slice to write the bytes into
Ok

When successful, returns the number of bytes written to buf. This method will never return Ok(0)