esp_hal::uart

Struct UartTx

pub struct UartTx<'d, M, T = AnyUart> { /* private fields */ }
UART (Transmit)

Implementations

Source

impl<'d, M, T> UartTx<'d, M, T>
where T: Instance, M: Mode,

pub fn with_rts( self, rts: impl Peripheral<P = impl PeripheralOutput> + 'd, ) -> Self

Configure RTS pin

pub fn apply_config(&mut self, config: &Config) -> Result<(), Error>

Change the configuration.

Note that this also changes the configuration of the RX half.

pub fn write_bytes(&mut self, data: &[u8]) -> Result<usize, Error>

Writes bytes

pub fn flush_tx(&mut self) -> Result<(), Error>

Flush the transmit buffer of the UART

Source

impl<'d> UartTx<'d, Blocking>

pub fn new( uart: impl Peripheral<P = impl Instance> + 'd, tx: impl Peripheral<P = impl PeripheralOutput> + 'd, ) -> Result<Self, Error>

Create a new UART TX instance in Blocking mode.

pub fn new_with_config( uart: impl Peripheral<P = impl Instance> + 'd, config: Config, tx: impl Peripheral<P = impl PeripheralOutput> + 'd, ) -> Result<Self, Error>

Create a new UART TX instance with configuration options in Blocking mode.

Source

impl<'d, T> UartTx<'d, Blocking, T>
where T: Instance,

pub fn new_typed( uart: impl Peripheral<P = T> + 'd, tx: impl Peripheral<P = impl PeripheralOutput> + 'd, ) -> Result<Self, Error>

Create a new UART TX instance in Blocking mode.

pub fn new_with_config_typed( uart: impl Peripheral<P = T> + 'd, config: Config, tx: impl Peripheral<P = impl PeripheralOutput> + 'd, ) -> Result<Self, Error>

Create a new UART TX instance with configuration options in Blocking mode.

pub fn into_async(self) -> UartTx<'d, Async, T>

Reconfigures the driver to operate in Async mode.

Source

impl<'d, T> UartTx<'d, Async, T>
where T: Instance,

pub fn into_blocking(self) -> UartTx<'d, Blocking, T>

Reconfigures the driver to operate in Blocking mode.

Source

impl<T> UartTx<'_, Async, T>
where T: Instance,

pub async fn write_async(&mut self, words: &[u8]) -> Result<usize, Error>

Asynchronously writes data to the UART transmit buffer in chunks.

This function sends the contents of the provided buffer words over the UART. Data is written in chunks to avoid overflowing the transmit FIFO, and the function waits asynchronously when necessary for space in the buffer to become available.

pub async fn flush_async(&mut self) -> Result<(), Error>

Asynchronously flushes the UART transmit buffer.

This function ensures that all pending data in the transmit FIFO has been sent over the UART. If the FIFO contains data, it waits for the transmission to complete before returning.